/* WARNING: This file is generated!
 * Do not edit this file, but edit /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_ru.xml instead and run
 * python configgen.py -wiz /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_ru.xml to regenerate this file!
 */
#include "configdoc.h"
#include "docintf.h"

void addConfigDocs_ru(DocIntf *doc)
{
  doc->setHeader(
              "Этот файл описывает настройки, используемые системой документирования Doxygen\n"
              "(www.doxygen.org) для проекта.\n"
              "\n"
              "Весь текст после двойной решётки (##) считается комментарием и помещается\n"
              "перед тегом, которому он предшествует.\n"
              "\n"
              "Весь текст после одинарной решётки (#) считается комментарием и будет\n"
              "проигнорирован. Формат следующий:\n"
              "TAG = value [value, ...]\n"
              "Для списков элементы также можно добавлять с помощью:\n"
              "TAG += value [value, ...]\n"
              "Значения, содержащие пробелы, следует заключать в кавычки (\" \").\n"
              "\n"
              "Примечание:\n"
              "\n"
              "Используйте Doxygen для сравнения используемого файла конфигурации с\n"
              "шаблонным файлом конфигурации:\n"
              "doxygen -x [configFile]\n"
              "Используйте Doxygen для сравнения используемого файла конфигурации с\n"
              "шаблонным файлом конфигурации без замены переменных окружения или переменных\n"
              "подстановки типа CMake:\n"
              "doxygen -x_noenv [configFile]"
             );
  doc->add(
              "DOXYFILE_ENCODING",
              "Этот тег указывает кодировку, используемую для всех символов в файле\n"
              "конфигурации, которые следуют за ним. Значение по умолчанию — UTF-8, которое\n"
              "также является кодировкой, используемой для всего текста перед первым\n"
              "появлением этого тега. Doxygen использует libiconv (или встроенный в libc\n"
              "iconv) для перекодирования. См. https://www.gnu.org/software/libiconv/ для\n"
              "списка возможных кодировок.\n"
              "Значение по умолчанию: UTF-8."
          );
  doc->add(
              "PROJECT_NAME",
              "Тег PROJECT_NAME — это одно слово (или последовательность слов, заключенная в\n"
              "двойные кавычки, если вы не используете Doxywizard), которое должно\n"
              "идентифицировать проект, для которого создается документация. Это имя\n"
              "используется в заголовке большинства сгенерированных страниц и в некоторых\n"
              "других местах.\n"
              "Значение по умолчанию: My Project."
          );
  doc->add(
              "PROJECT_NUMBER",
              "Тег PROJECT_NUMBER можно использовать для ввода номера проекта или ревизии.\n"
              "Это может быть полезно для архивирования сгенерированной документации или при\n"
              "использовании системы контроля версий."
          );
  doc->add(
              "PROJECT_BRIEF",
              "Используя тег PROJECT_BRIEF, можно предоставить необязательное однострочное\n"
              "описание проекта, которое появляется в верхней части каждой страницы и должно\n"
              "дать читателям быстрое представление о назначении проекта. Описание должно\n"
              "быть кратким."
          );
  doc->add(
              "PROJECT_LOGO",
              "С помощью тега PROJECT_LOGO можно указать логотип или значок, который будет\n"
              "включен в документацию. Максимальная высота логотипа не должна превышать 55\n"
              "пикселей, а максимальная ширина — 200 пикселей. Doxygen скопирует логотип в\n"
              "выходной каталог."
          );
  doc->add(
              "PROJECT_ICON",
              "С помощью тега PROJECT_ICON можно указать значок, который будет включен в\n"
              "вкладки при отображении HTML-документа. Doxygen скопирует логотип в выходной\n"
              "каталог."
          );
  doc->add(
              "OUTPUT_DIRECTORY",
              "Тег OUTPUT_DIRECTORY используется для указания (относительного или\n"
              "абсолютного) пути, по которому будет записана сгенерированная документация.\n"
              "Если введен относительный путь, он будет относительным к месту запуска\n"
              "Doxygen. Если оставить пустым, будет использоваться текущий каталог."
          );
  doc->add(
              "CREATE_SUBDIRS",
              "Если тег CREATE_SUBDIRS установлен в YES, Doxygen создаст до 4096 подкаталогов\n"
              "(на 2 уровнях) в выходном каталоге каждого выходного формата и распределит\n"
              "сгенерированные файлы по этим каталогам. Включение этой опции может быть\n"
              "полезно, когда Doxygen получает большое количество исходных файлов, и\n"
              "размещение всех сгенерированных файлов в одном каталоге может вызвать проблемы\n"
              "с производительностью файловой системы. Настройте CREATE_SUBDIRS_LEVEL для\n"
              "управления количеством подкаталогов.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "CREATE_SUBDIRS_LEVEL",
              "Управляет количеством подкаталогов, которые будут созданы, когда тег\n"
              "CREATE_SUBDIRS установлен в YES. Уровень 0 представляет 16 каталогов, и каждое\n"
              "увеличение уровня удваивает количество каталогов, что дает 4096 каталогов на\n"
              "уровне 8, который является значением по умолчанию и максимальным значением.\n"
              "Подкаталоги организованы в 2 уровня, первый уровень всегда имеет фиксированное\n"
              "количество 16 каталогов.\n"
              "Минимальное значение: 0, максимальное значение: 8, значение по умолчанию: 8.\n"
              "Этот тег требует, чтобы тег CREATE_SUBDIRS был установлен в YES."
          );
  doc->add(
              "ALLOW_UNICODE_NAMES",
              "Если тег ALLOW_UNICODE_NAMES установлен в YES, Doxygen разрешит появление не-\n"
              "ASCII символов в именах сгенерированных файлов. Если установлен в NO, не-ASCII\n"
              "символы будут экранированы, например, _xE3_x81_x84 будет использоваться для\n"
              "Unicode U+3044.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "OUTPUT_LANGUAGE",
              "Тег OUTPUT_LANGUAGE используется для указания языка, на котором будет написана\n"
              "вся документация, сгенерированная Doxygen. Doxygen будет использовать эту\n"
              "информацию для генерации всего постоянного вывода на соответствующем языке.\n"
              "Возможные значения:Afrikaans, Arabic, Armenian, Brazilian, Bulgarian, Catalan,\n"
              "Chinese, Chinese-Traditional, Croatian, Czech, Danish, Dutch, English (США),\n"
              "Esperanto, Farsi (Персидский), Finnish, French, German, Greek, Hindi,\n"
              "Hungarian, Indonesian, Italian, Japanese, Japanese-en (Японский с английскими\n"
              "сообщениями), Korean, Korean-en (Корейский с английскими сообщениями),\n"
              "Latvian, Lithuanian, Macedonian, Norwegian, Persian (Фарси), Polish,\n"
              "Portuguese, Romanian, Russian, Serbian, Serbian-Cyrillic, Slovak, Slovene,\n"
              "Spanish, Swedish, Turkish, UkrainianиVietnamese.\n"
              "Значение по умолчанию: English."
          );
  doc->add(
              "BRIEF_MEMBER_DESC",
              "Если тег BRIEF_MEMBER_DESC установлен в YES, Doxygen включит краткие описания\n"
              "членов после членов, перечисленных в документации файла и класса (аналогично\n"
              "Javadoc). Установите в NO, чтобы отключить это.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "REPEAT_BRIEF",
              "Если тег REPEAT_BRIEF установлен в YES, Doxygen добавит краткое описание члена\n"
              "или функции перед подробным описанием.\n"
              "\n"
              "Примечание: Если оба тега HIDE_UNDOC_MEMBERS и BRIEF_MEMBER_DESC установлены в\n"
              "NO, краткие описания будут полностью подавлены.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "ABBREVIATE_BRIEF",
              "Этот тег реализует почти интеллектуальный сокращатель кратких описаний,\n"
              "который используется для формирования текста в различных списках. Каждая\n"
              "строка в этом списке, если она найдена как начальный текст краткого описания,\n"
              "будет удалена из текста, и результат после обработки всего списка будет\n"
              "использован как аннотированный текст. В противном случае краткое описание\n"
              "используется как есть. Если оставить пустым, будут использоваться следующие\n"
              "значения ($name автоматически заменяется именем сущности):The $name class, The\n"
              "$name widget, The $name file, is, provides, specifies, contains, represents,\n"
              "a, anиthe."
          );
  doc->add(
              "ALWAYS_DETAILED_SEC",
              "Если оба тега ALWAYS_DETAILED_SEC и REPEAT_BRIEF установлены в YES, Doxygen\n"
              "сгенерирует подробный раздел, даже если есть только краткое описание.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "INLINE_INHERITED_MEMB",
              "Если тег INLINE_INHERITED_MEMB установлен в YES, Doxygen покажет все\n"
              "унаследованные члены в документации класса, как если бы эти члены были\n"
              "обычными членами класса. Конструкторы, деструкторы и операторы присваивания\n"
              "базового класса не будут показаны.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "FULL_PATH_NAMES",
              "Если тег FULL_PATH_NAMES установлен в YES, Doxygen добавит полный префикс пути\n"
              "к файлам в списке файлов и в заголовочных файлах. Если установлен в NO, будет\n"
              "использоваться самый короткий путь, который делает имена файлов уникальными.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "STRIP_FROM_PATH",
              "Тег STRIP_FROM_PATH можно использовать для удаления пользовательской части\n"
              "пути. Удаление выполняется только если одна из указанных строк совпадает с\n"
              "левой частью пути. Этот тег можно использовать для отображения относительных\n"
              "путей в списке файлов. Если оставить пустым, будет использоваться каталог, в\n"
              "котором запущен Doxygen, как путь для удаления.\n"
              "\n"
              "Обратите внимание, что вы можете указать здесь абсолютные пути, но также и\n"
              "относительные пути, которые будут относительными к каталогу, в котором был\n"
              "запущен Doxygen.\n"
              "Этот тег требует, чтобы тег FULL_PATH_NAMES был установлен в YES."
          );
  doc->add(
              "STRIP_FROM_INC_PATH",
              "Тег STRIP_FROM_INC_PATH можно использовать для удаления пользовательской части\n"
              "пути, упомянутой в документации класса, которая сообщает читателю, какой\n"
              "заголовочный файл нужно включить, чтобы использовать класс. Если оставить\n"
              "пустым, будет использоваться только имя заголовочного файла, содержащего\n"
              "определение класса. В противном случае вы должны указать список путей\n"
              "включения, которые обычно передаются компилятору с флагом -I."
          );
  doc->add(
              "SHORT_NAMES",
              "Если тег SHORT_NAMES установлен в YES, Doxygen будет генерировать более\n"
              "короткие (но менее читаемые) имена файлов. Это может быть полезно, если ваша\n"
              "файловая система не поддерживает длинные имена (как DOS, Mac или CD-ROM).\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "JAVADOC_AUTOBRIEF",
              "Если тег JAVADOC_AUTOBRIEF установлен в YES, Doxygen будет интерпретировать\n"
              "первую строку комментариев в стиле Javadoc (до первой точки, вопросительного\n"
              "знака или восклицательного знака) как краткое описание. Если установлен в NO,\n"
              "стиль Javadoc будет вести себя как обычные комментарии в стиле Qt (поэтому\n"
              "требуется явная команда @brief для получения краткого описания).\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "JAVADOC_BANNER",
              "Если тег JAVADOC_BANNER установлен в YES, Doxygen будет интерпретировать\n"
              "строки типа\n"
              "/***************\n"
              "как начало \"баннера\" комментария в стиле Javadoc. Если установлен в NO, стиль\n"
              "Javadoc будет вести себя как обычные комментарии, и Doxygen не будет\n"
              "интерпретировать его.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "QT_AUTOBRIEF",
              "Если тег QT_AUTOBRIEF установлен в YES, Doxygen будет интерпретировать первую\n"
              "строку комментариев в стиле Qt (до первой точки, вопросительного знака или\n"
              "восклицательного знака) как краткое описание. Если установлен в NO, стиль Qt\n"
              "будет вести себя как обычные комментарии в стиле Qt (поэтому требуется явная\n"
              "команда \\brief для получения краткого описания).\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "MULTILINE_CPP_IS_BRIEF",
              "Тег MULTILINE_CPP_IS_BRIEF можно установить в YES, чтобы Doxygen обрабатывал\n"
              "многострочные блоки специальных комментариев C++ (т.е. блоки комментариев //!\n"
              "или ///) как краткие описания. Это раньше было поведением по умолчанию. Новое\n"
              "значение по умолчанию — обрабатывать многострочные блоки комментариев C++ как\n"
              "подробные описания. Если вы предпочитаете старое поведение, установите этот\n"
              "тег в YES.\n"
              "\n"
              "Обратите внимание, что установка этого тега в YES также означает, что\n"
              "комментарии Rational Rose больше не будут распознаваться.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "PYTHON_DOCSTRING",
              "По умолчанию строки документации Python отображаются как предварительно\n"
              "отформатированный текст и не могут использовать специальные команды Doxygen.\n"
              "Установив PYTHON_DOCSTRING в NO, можно использовать специальные команды\n"
              "Doxygen, и содержимое блока документации строки документации будет\n"
              "отображаться как документация Doxygen.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "INHERIT_DOCS",
              "Если тег INHERIT_DOCS установлен в YES, недокументированный член унаследует\n"
              "документацию от любого документированного члена, который он переопределяет.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SEPARATE_MEMBER_PAGES",
              "Если тег SEPARATE_MEMBER_PAGES установлен в YES, Doxygen будет генерировать\n"
              "новую страницу для каждого члена. Если установлен в NO, документация члена\n"
              "станет частью файла/класса/пространства имен, который его содержит.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "TAB_SIZE",
              "Тег TAB_SIZE можно использовать для установки количества пробелов в табуляции.\n"
              "Doxygen использует это значение для замены табуляций пробелами во фрагментах\n"
              "кода.\n"
              "Минимальное значение: 1, максимальное значение: 16, значение по умолчанию: 4."
          );
  doc->add(
              "ALIASES",
              "Этот тег можно использовать для указания нескольких псевдонимов, которые будут\n"
              "действовать как команды в документации. Псевдоним имеет форму:\n"
              "имя=значение\n"
              "Например, добавление\n"
              "\"sideeffect=@par Побочные эффекты:^^\"\n"
              "позволит вам разместить команду \\sideeffect (или @sideeffect) в документации,\n"
              "что приведет к созданию пользовательского абзаца с заголовком \"Побочные\n"
              "эффекты:\". Обратите внимание, что вы не можете поместить \\n в часть значения\n"
              "псевдонима для вставки разрыва строки (в результирующем выводе). Вы можете\n"
              "поместить ^^ в часть значения псевдонима для вставки разрыва строки, как если\n"
              "бы в исходном файле был физический разрыв строки.Когда вам нужен литерал { или\n"
              "} или , в значении псевдонима, вам необходимо экранировать их с помощью\n"
              "обратной косой черты (\\), это может привести к конфликтам с командами \\{ и \\},\n"
              "для них рекомендуется использовать вариант @{ и @} или использовать двойное\n"
              "экранирование (\\\\{ и \\\\})"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_FOR_C",
              "Если ваш проект содержит только исходный код C, установите тег\n"
              "OPTIMIZE_OUTPUT_FOR_C в YES. Doxygen затем сгенерирует вывод, более\n"
              "адаптированный для C. Например, некоторые из используемых имен будут\n"
              "отличаться. Список всех членов будет опущен и т.д.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_JAVA",
              "Если ваш проект содержит только исходный код Java или Python, установите тег\n"
              "OPTIMIZE_OUTPUT_JAVA в YES. Doxygen затем сгенерирует вывод, более\n"
              "адаптированный для языка. Например, пространства имен будут отображаться как\n"
              "пакеты, квалифицированные области будут выглядеть иначе и т.д.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "OPTIMIZE_FOR_FORTRAN",
              "Если ваш проект содержит исходный код Fortran, установите тег\n"
              "OPTIMIZE_FOR_FORTRAN в YES. Doxygen затем сгенерирует вывод, подходящий для\n"
              "Fortran.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_VHDL",
              "Если ваш проект содержит исходный код VHDL, установите тег\n"
              "OPTIMIZE_OUTPUT_VHDL в YES. Doxygen затем сгенерирует вывод, подходящий для\n"
              "VHDL.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_SLICE",
              "Если ваш проект содержит только исходный код Slice, установите тег\n"
              "OPTIMIZE_OUTPUT_SLICE в YES. Doxygen затем сгенерирует вывод, более\n"
              "адаптированный для языка. Например, пространства имен будут отображаться как\n"
              "модули, типы будут разделены на больше групп и т.д.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTENSION_MAPPING",
              "Doxygen выбирает парсер для использования на основе расширения анализируемого\n"
              "файла. С этим тегом вы можете назначить парсер для использования с данным\n"
              "расширением. Doxygen имеет встроенное сопоставление, но вы можете\n"
              "переопределить или расширить его с помощью этого тега. Формат: ext=language,\n"
              "где ext — расширение файла, а language — один из парсеров, поддерживаемых\n"
              "Doxygen: IDL, Java, JavaScript, Csharp (C#), C, C++, Lex, D, PHP, md\n"
              "(Markdown), Objective-C, Python, Slice, VHDL, Fortran (Fortran с фиксированным\n"
              "форматом: FortranFixed, Fortran со свободным форматом: FortranFree, Fortran с\n"
              "неизвестным форматом: Fortran. В последнем случае парсер попытается угадать,\n"
              "является ли код фиксированным или свободным форматом, что является значением\n"
              "по умолчанию для файлов типа Fortran). Например, чтобы Doxygen обрабатывал\n"
              "файлы .inc как файлы Fortran (по умолчанию PHP), а файлы .f как файлы C (по\n"
              "умолчанию Fortran), используйте: inc=Fortran f=C.\n"
              "\n"
              "Примечание: Для файлов без расширения вы можете использовать no_extension как\n"
              "заполнитель.\n"
              "\n"
              "Обратите внимание, что для пользовательских расширений вам также нужно\n"
              "установить FILE_PATTERNS, иначе Doxygen не будет читать эти файлы. Когда\n"
              "указан no_extension, вы должны добавить * в FILE_PATTERNS.\n"
              "\n"
              "Примечание, см. также список сопоставления расширений файлов по умолчанию."
          );
  doc->add(
              "MARKDOWN_SUPPORT",
              "Если тег MARKDOWN_SUPPORT включен, Doxygen будет предварительно обрабатывать\n"
              "все комментарии в соответствии с форматом Markdown, что позволяет создавать\n"
              "более читаемую документацию. См. https://daringfireball.net/projects/markdown/\n"
              "для получения дополнительной информации. Вывод обработки Markdown\n"
              "дополнительно обрабатывается Doxygen, поэтому вы можете смешивать команды\n"
              "Doxygen, HTML и XML с форматированием Markdown. Отключайте это только в случае\n"
              "проблем с обратной совместимостью.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "MARKDOWN_STRICT",
              "Если тег MARKDOWN_STRICT включен, Doxygen будет обрабатывать текст в\n"
              "комментариях как формат Markdown, даже если собственный формат разметки\n"
              "Doxygen конфликтует с Markdown. Это актуально только при использовании\n"
              "обратных кавычек. Собственный стиль разметки Doxygen позволяет одинарной\n"
              "кавычке закрывать фрагмент текста, начинающийся с обратной кавычки, который\n"
              "затем рассматривается как цитируемый фрагмент текста, в то время как в\n"
              "Markdown такие фрагменты текста рассматриваются как буквальный текст и\n"
              "закрываются только при нахождении второй соответствующей обратной кавычки.\n"
              "Кроме того, собственный формат разметки Doxygen требует, чтобы двойные кавычки\n"
              "в разделе с обратными кавычками экранировались при их появлении, в то время\n"
              "как Markdown этого не требует.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег MARKDOWN_SUPPORT был установлен в YES."
          );
  doc->add(
              "TOC_INCLUDE_HEADINGS",
              "Когда тег TOC_INCLUDE_HEADINGS установлен в ненулевое значение, все заголовки\n"
              "до этого уровня будут автоматически включены в оглавление, даже если у них нет\n"
              "атрибута id.\n"
              "Примечание: Эта функция в настоящее время работает только для заголовков\n"
              "Markdown.\n"
              "Минимальное значение: 0, максимальное значение: 99, значение по умолчанию: 6.\n"
              "Этот тег требует, чтобы тег MARKDOWN_SUPPORT был установлен в YES."
          );
  doc->add(
              "MARKDOWN_ID_STYLE",
              "Тег MARKDOWN_ID_STYLE можно использовать для указания алгоритма, используемого\n"
              "для генерации идентификаторов для заголовков Markdown. Примечание: Каждый\n"
              "идентификатор уникален.\n"
              "Возможные значения:DOXYGEN использовать фиксированную строку 'autotoc_md' с\n"
              "порядковым номером, начиная с 0иGITHUB использовать версию заголовка в нижнем\n"
              "регистре, заменяя пробелы на '-' и удаляя знаки препинания.\n"
              "Значение по умолчанию: DOXYGEN.\n"
              "Этот тег требует, чтобы тег MARKDOWN_SUPPORT был установлен в YES."
          );
  doc->add(
              "AUTOLINK_SUPPORT",
              "Когда включено, Doxygen будет пытаться связать слова, соответствующие\n"
              "документированному классу или пространству имен, с соответствующей\n"
              "документацией. Это можно предотвратить в отдельных случаях, поместив символ %\n"
              "перед словом, или глобально, установив AUTOLINK_SUPPORT в NO. Слова,\n"
              "перечисленные в теге AUTOLINK_IGNORE_WORDS, исключаются из автоматического\n"
              "связывания.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "AUTOLINK_IGNORE_WORDS",
              "Этот тег указывает список слов, которые при совпадении с началом слова в\n"
              "документации будут подавлять генерацию автоматических ссылок, если\n"
              "автоматическое связывание включено через AUTOLINK_SUPPORT. Этот список не\n"
              "влияет на ссылки, созданные явно с помощью команд # или \\link или \\ref.\n"
              "Этот тег требует, чтобы тег AUTOLINK_SUPPORT был установлен в YES."
          );
  doc->add(
              "BUILTIN_STL_SUPPORT",
              "Если вы используете классы STL (т.е. std::string, std::vector и т.д.), но не\n"
              "хотите включать исходный код (файл тегов) STL в качестве входных данных, вы\n"
              "должны установить этот тег в YES, чтобы Doxygen мог сопоставлять объявления и\n"
              "определения функций, чьи аргументы содержат классы STL (например,\n"
              "func(std::string); с func(std::string) {}). Это также делает диаграммы\n"
              "наследования и сотрудничества, включающие классы STL, более полными и точными.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "CPP_CLI_SUPPORT",
              "Если вы используете язык C++/CLI от Microsoft, вы должны установить эту опцию\n"
              "в YES для включения поддержки синтаксического анализа.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "SIP_SUPPORT",
              "Если ваш проект содержит только sip (see:\n"
              "https://www.riverbankcomputing.com/software) исходный код, установите тег\n"
              "SIP_SUPPORT в YES. Doxygen будет анализировать их как обычный C++, но будет\n"
              "предполагать, что все классы используют публичное наследование, когда нет\n"
              "явного ключевого слова защиты, вместо приватного наследования.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "IDL_PROPERTY_SUPPORT",
              "Для Microsoft IDL существуют атрибуты propget и propput для указания методов\n"
              "getter и setter для свойств. Установка этой опции в YES заставит Doxygen\n"
              "заменять методы get и set в документации на свойство. Это работает только если\n"
              "методы действительно получают или устанавливают простой тип. Если это не так,\n"
              "или вы хотите отображать методы в любом случае, вы должны установить эту опцию\n"
              "в NO.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "DISTRIBUTE_GROUP_DOC",
              "Если в документации используется группировка членов и тег DISTRIBUTE_GROUP_DOC\n"
              "установлен в YES, то Doxygen повторно использует документацию первого члена\n"
              "группы для других членов группы (если она есть). По умолчанию все члены группы\n"
              "должны быть явно документированы.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "GROUP_NESTED_COMPOUNDS",
              "Если структура или класс добавлены в группу и эта опция включена, любые\n"
              "вложенные классы или структуры также будут добавлены в ту же группу. По\n"
              "умолчанию эта опция отключена, и вложенные составные типы должны быть\n"
              "добавлены явно через \\ingroup.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "SUBGROUPING",
              "Установите тег SUBGROUPING в YES, чтобы разрешить группам членов класса одного\n"
              "типа (например, группу публичных функций) быть помещенными в подгруппу этого\n"
              "типа (например, в разделе Публичные функции). Установите в NO, чтобы\n"
              "предотвратить подгруппировку. Альтернативно, это можно сделать для каждого\n"
              "класса с помощью команды \\nosubgrouping.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "INLINE_GROUPED_CLASSES",
              "Когда тег INLINE_GROUPED_CLASSES установлен в YES, классы, структуры и\n"
              "объединения отображаются в содержащей их группе (например, с использованием\n"
              "\\ingroup), а не на отдельных страницах (для HTML и страниц Man) или в разделах\n"
              "(для LaTeX и RTF).\n"
              "\n"
              "Обратите внимание, что эта функция не может быть объединена с\n"
              "SEPARATE_MEMBER_PAGES.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "INLINE_SIMPLE_STRUCTS",
              "Когда тег INLINE_SIMPLE_STRUCTS установлен в YES, структуры, классы и\n"
              "объединения, которые имеют только публичные поля данных или простые поля\n"
              "typedef, будут отображаться в документации области, в которой они определены\n"
              "(т.е. документация файла, пространства имен или группы), при условии, что эта\n"
              "область документирована. Если установлено в NO, структуры, классы и\n"
              "объединения будут отображаться на отдельных страницах (для HTML и страниц Man)\n"
              "или в разделах (для LaTeX и RTF).\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "TYPEDEF_HIDES_STRUCT",
              "Когда тег TYPEDEF_HIDES_STRUCT включен, typedef для структуры, объединения или\n"
              "перечисления будет документирован как структура, объединение или перечисление\n"
              "с именем typedef. Таким образом, typedef struct TypeS {} TypeT будет\n"
              "отображаться в документации как структура с именем TypeT. Когда отключено,\n"
              "typedef будет отображаться как член файла, пространства имен или класса.\n"
              "Структура будет называться TypeS. Это обычно полезно для кода C, если\n"
              "соглашение о кодировании требует, чтобы все составные типы были typedef, и на\n"
              "typedef ссылаются только по имени, никогда по имени тега.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "LOOKUP_CACHE_SIZE",
              "Размер кэша поиска символов можно установить с помощью LOOKUP_CACHE_SIZE. Этот\n"
              "кэш используется для разрешения символов на основе их имени и области\n"
              "видимости. Поскольку это может быть дорогостоящим процессом, и обычно одни и\n"
              "те же символы появляются много раз в коде, Doxygen поддерживает кэш\n"
              "предварительно проанализированных символов. Если кэш слишком мал, Doxygen\n"
              "станет медленнее. Если кэш слишком велик, память будет потрачена впустую.\n"
              "Размер кэша определяется следующей формулой: 2^(16+LOOKUP_CACHE_SIZE).\n"
              "Допустимый диапазон — 0..9, значение по умолчанию — 0, что соответствует\n"
              "размеру кэша в 2^16=65536 символов. В конце выполнения Doxygen сообщит об\n"
              "использовании кэша и предложит оптимальный размер кэша с точки зрения\n"
              "скорости.\n"
              "Минимальное значение: 0, максимальное значение: 9, значение по умолчанию: 0."
          );
  doc->add(
              "NUM_PROC_THREADS",
              "NUM_PROC_THREADS указывает количество потоков, которые Doxygen может\n"
              "использовать во время обработки. Когда установлено в 0, Doxygen установит его\n"
              "на основе количества ядер, доступных в системе. Вы можете установить его явно\n"
              "в значение больше 0, чтобы лучше контролировать баланс между нагрузкой на ЦП и\n"
              "скоростью обработки. В настоящее время только обработка входных данных может\n"
              "выполняться несколькими потоками. Поскольку это все еще экспериментальная\n"
              "функция, значение по умолчанию установлено в 1, что фактически отключает\n"
              "параллельную обработку. Пожалуйста, сообщайте о любых проблемах, с которыми вы\n"
              "столкнулись. Параллельная генерация диаграмм dot управляется настройкой\n"
              "DOT_NUM_THREADS.\n"
              "Минимальное значение: 0, максимальное значение: 512, значение по умолчанию: 1."
          );
  doc->add(
              "TIMESTAMP",
              "Если тег TIMESTAMP установлен в значение, отличное от NO, каждая\n"
              "сгенерированная страница будет содержать дату или дату и время, когда страница\n"
              "была сгенерирована. Установка в NO помогает сравнивать вывод нескольких\n"
              "запусков.\n"
              "Возможные значения:YES, NO, DATETIMEиDATE.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTRACT_ALL",
              "Если тег EXTRACT_ALL установлен в YES, Doxygen будет предполагать, что все\n"
              "сущности в документации документированы, даже если документация недоступна.\n"
              "Закрытые члены класса и статические члены файла будут скрыты, если только теги\n"
              "EXTRACT_PRIVATE или EXTRACT_STATIC не установлены в YES соответственно.\n"
              "Примечание: Это также отключит предупреждения о недокументированных членах,\n"
              "которые обычно генерируются, когда WARNINGS установлен в YES.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTRACT_PRIVATE",
              "Если тег EXTRACT_PRIVATE установлен в YES, все закрытые члены класса будут\n"
              "включены в документацию.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTRACT_PRIV_VIRTUAL",
              "Если тег EXTRACT_PRIV_VIRTUAL установлен в YES, документированные закрытые\n"
              "виртуальные методы класса будут включены в документацию.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTRACT_PACKAGE",
              "Если тег EXTRACT_PACKAGE установлен в YES, все члены с областью видимости\n"
              "пакета или внутренней областью будут включены в документацию.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTRACT_STATIC",
              "Если тег EXTRACT_STATIC установлен в YES, все статические члены файла будут\n"
              "включены в документацию.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTRACT_LOCAL_CLASSES",
              "Если тег EXTRACT_LOCAL_CLASSES установлен в YES, классы (и структуры),\n"
              "определенные локально в исходных файлах, будут включены в документацию. Если\n"
              "установлено в NO, будут включены только классы, определенные в заголовочных\n"
              "файлах. Не влияет на исходный код Java.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "EXTRACT_LOCAL_METHODS",
              "Этот флаг полезен только для кода Objective-C. Если установлен в YES,\n"
              "локальные методы, определенные в разделе реализации, но не в интерфейсе, будут\n"
              "включены в документацию. Если установлено в NO, будут включены только методы в\n"
              "интерфейсе.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTRACT_ANON_NSPACES",
              "Если этот флаг установлен в YES, члены анонимных пространств имен будут\n"
              "извлечены и показаны в документации как пространство имен с именем\n"
              "'anonymous_namespace{file}', где file заменяется базовым именем файла,\n"
              "содержащего анонимное пространство имен. По умолчанию анонимные пространства\n"
              "имен скрыты.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "RESOLVE_UNNAMED_PARAMS",
              "Если этот флаг установлен в YES, имя неименованных параметров в объявлении\n"
              "будет определено соответствующим определением. По умолчанию неименованные\n"
              "параметры остаются безымянными в выводе.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "HIDE_UNDOC_MEMBERS",
              "Если тег HIDE_UNDOC_MEMBERS установлен в YES, Doxygen скроет все\n"
              "недокументированные члены внутри документированных классов или файлов. Если\n"
              "установлено в NO, эти члены будут включены в различные обзоры, но раздел\n"
              "документации не будет сгенерирован. Эта опция не имеет эффекта, если\n"
              "EXTRACT_ALL включен.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "HIDE_UNDOC_CLASSES",
              "Если тег HIDE_UNDOC_CLASSES установлен в YES, Doxygen скроет все\n"
              "недокументированные классы, которые обычно были бы видны в иерархии классов.\n"
              "Если установлено в NO, эти классы будут включены в различные обзоры. Если\n"
              "включено, эта опция также скроет недокументированные концепции C++. Эта опция\n"
              "не имеет эффекта, если EXTRACT_ALL включен.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "HIDE_UNDOC_NAMESPACES",
              "Если тег HIDE_UNDOC_NAMESPACES установлен в YES, Doxygen скроет все\n"
              "недокументированные пространства имен, которые обычно были бы видны в иерархии\n"
              "пространств имен. Если установлено в NO, эти пространства имен будут включены\n"
              "в различные обзоры. Эта опция не имеет эффекта, если EXTRACT_ALL включен.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "HIDE_FRIEND_COMPOUNDS",
              "Если тег HIDE_FRIEND_COMPOUNDS установлен в YES, Doxygen скроет все объявления\n"
              "friend. Если установлено в NO, эти объявления будут включены в документацию.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "HIDE_IN_BODY_DOCS",
              "Если тег HIDE_IN_BODY_DOCS установлен в YES, Doxygen скроет любые блоки\n"
              "документации, найденные внутри тела функции. Если установлено в NO, эти блоки\n"
              "будут добавлены к подробному блоку документации функции.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "INTERNAL_DOCS",
              "Тег INTERNAL_DOCS определяет, будет ли включена документация, написанная после\n"
              "команды \\internal. Если тег установлен в NO, документация будет исключена.\n"
              "Установите в YES, чтобы включить внутреннюю документацию.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "CASE_SENSE_NAMES",
              "Правильно установив опцию CASE_SENSE_NAMES, Doxygen сможет лучше\n"
              "адаптироваться к возможностям базовой файловой системы. Если файловая система\n"
              "чувствительна к регистру (т.е. поддерживает файлы в одном каталоге, имена\n"
              "которых отличаются только регистром), вы должны установить опцию в YES, чтобы\n"
              "правильно обрабатывать такие файлы, которые появляются во входных данных. Для\n"
              "файловых систем, не чувствительных к регистру, вы должны установить опцию в\n"
              "NO, чтобы правильно обрабатывать выходные файлы, записанные для символов,\n"
              "которые отличаются только регистром, например, для двух классов, один с именем\n"
              "CLASS, а другой с именем Class, а также для поддержки ссылки на файлы без\n"
              "указания точного регистра. В Windows (включая Cygwin) и macOS пользователи\n"
              "обычно должны установить эту опцию в NO, в то время как в Linux или других\n"
              "системах Unix она обычно должна быть установлена в YES.\n"
              "Возможные значения:SYSTEM, NOиYES.\n"
              "Значение по умолчанию: SYSTEM."
          );
  doc->add(
              "HIDE_SCOPE_NAMES",
              "Если тег HIDE_SCOPE_NAMES установлен в NO, Doxygen будет показывать члены с их\n"
              "полным классом и областью пространства имен в документации. Если установлено в\n"
              "YES, область будет скрыта.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "HIDE_COMPOUND_REFERENCE",
              "Если тег HIDE_COMPOUND_REFERENCE установлен в NO (по умолчанию), Doxygen\n"
              "добавит дополнительный текст после заголовка страницы, например, Справочник\n"
              "класса. Если установлено в YES, ссылка на составной тип будет скрыта.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "SHOW_HEADERFILE",
              "Если тег SHOW_HEADERFILE установлен в YES, документация класса покажет, какой\n"
              "заголовочный файл нужно включить, чтобы использовать класс.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SHOW_INCLUDE_FILES",
              "Если тег SHOW_INCLUDE_FILES установлен в YES, Doxygen поместит список файлов,\n"
              "включенных файлом, в документацию этого файла.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SHOW_GROUPED_MEMB_INC",
              "Если тег SHOW_GROUPED_MEMB_INC установлен в YES, Doxygen будет показывать\n"
              "директивы включения для членов, которые были сгруппированы в файловой\n"
              "документации, в том порядке, в котором они встречаются в исходном коде.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "FORCE_LOCAL_INCLUDES",
              "Если тег FORCE_LOCAL_INCLUDES установлен в YES, файлы включения в документации\n"
              "функций, которые являются членами группы, будут записаны с двойными кавычками\n"
              "вместо угловых скобок.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "INLINE_INFO",
              "Если тег INLINE_INFO установлен в YES, раздел с встроенной информацией будет\n"
              "включен в документацию, показывающий, какие функции являются встроенными.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SORT_MEMBER_DOCS",
              "Если тег SORT_MEMBER_DOCS установлен в YES, Doxygen отсортирует (подробную)\n"
              "документацию членов файла и класса в алфавитном порядке по имени члена. Если\n"
              "установлено в NO, члены появятся в порядке объявления.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SORT_BRIEF_DOCS",
              "Если тег SORT_BRIEF_DOCS установлен в YES, Doxygen отсортирует краткие\n"
              "описания членов файла, пространства имен и класса в алфавитном порядке по\n"
              "имени члена. Если установлено в NO, члены появятся в порядке объявления.\n"
              "Обратите внимание, что это также повлияет на порядок классов в списке классов.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "SORT_MEMBERS_CTORS_1ST",
              "Если тег SORT_MEMBERS_CTORS_1ST установлен в YES, Doxygen отсортирует (краткую\n"
              "и подробную) документацию членов класса так, чтобы конструкторы и деструкторы\n"
              "были перечислены первыми. Если установлено в NO, конструкторы появятся в\n"
              "соответствующих порядках, определенных SORT_BRIEF_DOCS и SORT_MEMBER_DOCS.\n"
              "Примечание: Если SORT_BRIEF_DOCS установлен в NO, эта опция игнорируется при\n"
              "сортировке краткой документации членов.\n"
              "Примечание: Если SORT_MEMBER_DOCS установлен в NO, эта опция игнорируется при\n"
              "сортировке подробной документации членов.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "SORT_GROUP_NAMES",
              "Если тег SORT_GROUP_NAMES установлен в YES, Doxygen отсортирует иерархию имен\n"
              "групп в алфавитном порядке. Если установлено в NO, имена групп появятся в\n"
              "порядке их определения.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "SORT_BY_SCOPE_NAME",
              "Если тег SORT_BY_SCOPE_NAME установлен в YES, список классов будет\n"
              "отсортирован по полным именам (включая пространство имен). Если установлено в\n"
              "NO, список классов будет отсортирован только по имени класса, исключая часть\n"
              "пространства имен.\n"
              "Примечание: Если HIDE_SCOPE_NAMES установлен в YES, эта опция менее полезна.\n"
              "Примечание: Эта опция применяется только к списку классов, а не к алфавитному\n"
              "списку.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "STRICT_PROTO_MATCHING",
              "Если опция STRICT_PROTO_MATCHING включена и Doxygen не может правильно\n"
              "проанализировать все типы аргументов функции, он отклонит соответствие между\n"
              "прототипом и реализацией функции-члена, даже если есть только один кандидат\n"
              "или если очевидно из простого строкового сопоставления, какой кандидат должен\n"
              "быть выбран. Отключение STRICT_PROTO_MATCHING все равно позволит Doxygen\n"
              "принимать соответствие между прототипом и реализацией в таком случае.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "GENERATE_TODOLIST",
              "Тег GENERATE_TODOLIST можно использовать для включения (YES) или отключения\n"
              "(NO) списка задач. Этот список создается путем размещения команд \\todo в\n"
              "документации.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "GENERATE_TESTLIST",
              "Тег GENERATE_TESTLIST можно использовать для включения (YES) или отключения\n"
              "(NO) списка тестов. Этот список создается путем размещения команд \\test в\n"
              "документации.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "GENERATE_BUGLIST",
              "Тег GENERATE_BUGLIST можно использовать для включения (YES) или отключения\n"
              "(NO) списка ошибок. Этот список создается путем размещения команд \\bug в\n"
              "документации.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "GENERATE_DEPRECATEDLIST",
              "Тег GENERATE_DEPRECATEDLIST можно использовать для включения (YES) или\n"
              "отключения (NO) списка устаревших. Этот список создается путем размещения\n"
              "команд \\deprecated в документации.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "GENERATE_REQUIREMENTS",
              "Тег GENERATE_REQUIREMENTS можно использовать для включения (YES) или\n"
              "отключения (NO) страницы требований. Когда включено, эта страница создается\n"
              "автоматически, когда во входных данных появляется хотя бы один блок\n"
              "комментариев с командой \\requirement.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "REQ_TRACEABILITY_INFO",
              "Тег REQ_TRACEABILITY_INFO управляет отображением информации о прослеживаемости\n"
              "на странице требований (актуально только при использовании блоков комментариев\n"
              "\\requirement). Установка в NO полностью отключит информацию о\n"
              "прослеживаемости. Установка в UNSATISFIED_ONLY покажет список требований,\n"
              "которым не хватает отношения удовлетворения (через команду: \\satisfies).\n"
              "Аналогично, установка в UNVERIFIED_ONLY покажет список требований, которым не\n"
              "хватает отношения верификации (через команду: \\verifies). Установка тега в YES\n"
              "(по умолчанию) покажет оба списка, когда применимо.\n"
              "Возможные значения:YES, NO, UNSATISFIED_ONLYиUNVERIFIED_ONLY.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_REQUIREMENTS был установлен в YES."
          );
  doc->add(
              "ENABLED_SECTIONS",
              "Тег ENABLED_SECTIONS можно использовать для включения условных разделов\n"
              "документации, помеченных блоками \\if <section_label> ... \\endif и \\cond\n"
              "<section_label> ... \\endcond."
          );
  doc->add(
              "MAX_INITIALIZER_LINES",
              "Тег MAX_INITIALIZER_LINES определяет максимальное количество строк, которое\n"
              "начальное значение переменной или макроса/определения может отображать, чтобы\n"
              "появиться в документации. Если инициализатор содержит больше строк, чем\n"
              "указано здесь, он будет скрыт. Используйте значение 0, чтобы полностью скрыть\n"
              "инициализатор. Внешний вид значения отдельных переменных и\n"
              "макросов/определений можно контролировать в документации с помощью команд\n"
              "\\showinitializer или \\hideinitializer, независимо от этой настройки.\n"
              "Минимальное значение: 0, максимальное значение: 10000, значение по умолчанию:\n"
              "30."
          );
  doc->add(
              "SHOW_USED_FILES",
              "Установите тег SHOW_USED_FILES в NO, чтобы отключить список файлов,\n"
              "генерируемый в нижней части документации классов и структур. Если установлено\n"
              "в YES, в списке будут упомянуты файлы, которые использовались для генерации\n"
              "документации.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SHOW_FILES",
              "Установите тег SHOW_FILES в NO, чтобы отключить генерацию страниц файлов. Это\n"
              "удалит записи файлов из быстрого индекса и из древовидного представления папок\n"
              "(если указано).\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SHOW_NAMESPACES",
              "Установите тег SHOW_NAMESPACES в NO, чтобы отключить генерацию страниц\n"
              "пространств имен. Это удалит записи пространств имен из быстрого индекса и из\n"
              "древовидного представления папок (если указано).\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "FILE_VERSION_FILTER",
              "Тег FILE_VERSION_FILTER можно использовать для указания программы или скрипта,\n"
              "который Doxygen должен вызвать для получения текущей версии каждого файла\n"
              "(обычно из системы контроля версий). Doxygen вызовет программу, выполнив\n"
              "(через popen()) команду command input_file, где command — значение тега\n"
              "FILE_VERSION_FILTER, а input_file — имя входного файла, предоставленного\n"
              "Doxygen. Все, что программа выведет в стандартный вывод, будет использовано\n"
              "как версия файла.Пример см. в документации."
          );
  doc->add(
              "LAYOUT_FILE",
              "Тег LAYOUT_FILE можно использовать для указания файла макета, который Doxygen\n"
              "проанализирует. Файл макета управляет глобальной структурой сгенерированных\n"
              "выходных файлов независимым от формата вывода способом. Чтобы создать файл\n"
              "макета, представляющий настройки Doxygen по умолчанию, запустите Doxygen с\n"
              "опцией -l. Вы можете опционально указать имя файла после опции, если опустите,\n"
              "DoxygenLayout.xml будет использовано как имя файла макета. См. также раздел\n"
              "\"Changing the layout of pages\" для информации.\n"
              "\n"
              "Обратите внимание, что если вы запускаете Doxygen из каталога, содержащего\n"
              "файл с именем DoxygenLayout.xml, Doxygen автоматически проанализирует его,\n"
              "даже если тег LAYOUT_FILE пуст."
          );
  doc->add(
              "CITE_BIB_FILES",
              "Тег CITE_BIB_FILES можно использовать для указания одного или нескольких\n"
              "файлов bib, содержащих определения ссылок. Это должен быть список файлов .bib.\n"
              "Расширение .bib будет добавлено автоматически, если опущено. Это требует,\n"
              "чтобы инструмент bibtex был установлен. См. также\n"
              "https://en.wikipedia.org/wiki/BibTeX для дополнительной информации. Для LaTeX\n"
              "стиль ссылок может контролироваться с помощью LATEX_BIB_STYLE. Чтобы\n"
              "использовать эту функцию, вам нужно иметь bibtex и perl доступными в пути\n"
              "поиска. См. также \\cite для информации о создании цитат."
          );
  doc->add(
              "EXTERNAL_TOOL_PATH",
              "Тег EXTERNAL_TOOL_PATH можно использовать для расширения пути поиска\n"
              "(переменная окружения PATH), чтобы внешние инструменты, такие как latex и gs,\n"
              "могли быть найдены.\n"
              "Примечание: Каталоги, указанные с EXTERNAL_TOOL_PATH, добавляются перед\n"
              "путями, уже указанными переменной PATH, и добавляются в указанном порядке.\n"
              "Примечание: Эта опция особенно полезна для macOS версии 14 (Sonoma) и выше,\n"
              "когда Doxygen запускается из Doxywizard, потому что в этом случае любые\n"
              "пользовательские изменения PATH игнорируются. Типичный пример на macOS —\n"
              "установить\n"
              "EXTERNAL_TOOL_PATH = /Library/TeX/texbin /usr/local/bin\n"
              "Вместе со стандартными путями полный путь поиска, который Doxygen использует\n"
              "при запуске внешних инструментов, станет\n"
              "PATH=/Library/TeX/texbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
          );
  doc->add(
              "QUIET",
              "Тег QUIET можно использовать для включения/выключения сообщений, генерируемых\n"
              "Doxygen на стандартный вывод. Если QUIET установлен в YES, это означает, что\n"
              "сообщения выключены.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "WARNINGS",
              "Тег WARNINGS можно использовать для включения/выключения предупреждающих\n"
              "сообщений, генерируемых Doxygen на стандартный поток ошибок (stderr). Если\n"
              "WARNINGS установлен в YES, это означает, что предупреждения включены.\n"
              "\n"
              "Совет: Включите предупреждения при написании документации.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "WARN_IF_UNDOCUMENTED",
              "Если тег WARN_IF_UNDOCUMENTED установлен в YES, Doxygen будет генерировать\n"
              "предупреждения для недокументированных членов. Если EXTRACT_ALL установлен в\n"
              "YES, этот флаг будет автоматически отключен.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "WARN_IF_DOC_ERROR",
              "Если тег WARN_IF_DOC_ERROR установлен в YES, Doxygen будет генерировать\n"
              "предупреждения о потенциальных ошибках в документации, таких как\n"
              "документирование некоторых параметров в документированной функции дважды, или\n"
              "документирование несуществующих параметров, или неправильное использование\n"
              "команд разметки.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "WARN_IF_INCOMPLETE_DOC",
              "Если тег WARN_IF_INCOMPLETE_DOC установлен в YES, Doxygen будет генерировать\n"
              "предупреждения о потенциально неполной документации, такой как отсутствие\n"
              "документации всех параметров функции или отсутствие документации возвращаемого\n"
              "значения, когда функция имеет тип возврата, отличный от void.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "WARN_NO_PARAMDOC",
              "Параметр WARN_NO_PARAMDOC можно включить для получения предупреждений о\n"
              "функциях, которые задокументированы, но не имеют документации для своих\n"
              "параметров или возвращаемого значения. Если установлен в NO, Doxygen будет\n"
              "предупреждать только о неправильной документации параметров, но не об её\n"
              "отсутствии. Если EXTRACT_ALL установлен в YES, этот флаг будет автоматически\n"
              "отключён. См. также WARN_IF_INCOMPLETE_DOC\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "WARN_IF_UNDOC_ENUM_VAL",
              "Если тег WARN_IF_UNDOC_ENUM_VAL установлен в YES, Doxygen будет генерировать\n"
              "предупреждения для недокументированных значений перечислений. Если EXTRACT_ALL\n"
              "установлен в YES, этот флаг будет автоматически отключен.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "WARN_LAYOUT_FILE",
              "Если тег WARN_LAYOUT_FILE установлен в YES, Doxygen будет предупреждать, если\n"
              "файл макета указан и не может быть найден. Если установлено в NO, Doxygen\n"
              "молча использует файл макета по умолчанию.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "WARN_AS_ERROR",
              "Если тег WARN_AS_ERROR установлен в NO (по умолчанию), предупреждения не\n"
              "влияют на код возврата Doxygen. Если тег установлен в YES, все предупреждения\n"
              "будут рассматриваться как ошибки и Doxygen остановится после отображения\n"
              "первого предупреждения. Если тег установлен в FAIL_ON_WARNINGS, Doxygen\n"
              "сначала напечатает все найденные предупреждения и ошибки, а затем остановится.\n"
              "Если тег установлен в FAIL_ON_WARNINGS_PRINT, Doxygen будет вести себя так же,\n"
              "как при FAIL_ON_WARNINGS, но в дополнение все предупреждения и ошибки будут\n"
              "также записаны в файл, указанный параметром WARN_LOGFILE (если он задан),\n"
              "после чего завершит работу с ненулевым кодом возврата.\n"
              "Возможные значения:NO, YES, FAIL_ON_WARNINGSиFAIL_ON_WARNINGS_PRINT.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "WARN_FORMAT",
              "Тег WARN_FORMAT определяет формат выводимых Doxygen предупреждений. Строка\n"
              "должна содержать метки $file, $line и $text, которые будут заменены именем\n"
              "файла, номером строки и текстом предупреждения соответственно. Опционально\n"
              "можно использовать метку $version, которая будет заменена версией файла (если\n"
              "она может быть получена через FILE_VERSION_FILTER)\n"
              "См. также: WARN_LINE_FORMAT\n"
              "Значение по умолчанию: $file:$line: $text."
          );
  doc->add(
              "WARN_LINE_FORMAT",
              "В части $text команды WARN_FORMAT может быть указана ссылка на более\n"
              "конкретное место. Чтобы облегчить переход к этому месту (вне Doxygen),\n"
              "пользователь может определить пользовательскую строку \"вырезать\" / \"вставить\".\n"
              "Пример:\n"
              "WARN_LINE_FORMAT = \"'vi $file +$line'\"\n"
              "См. также: WARN_FORMAT\n"
              "Значение по умолчанию: at line $line of file $file."
          );
  doc->add(
              "WARN_LOGFILE",
              "Тег WARN_LOGFILE можно использовать для указания файла, в который будут\n"
              "записываться предупреждения и ошибки. Если не задан или пуст, предупреждения\n"
              "выводятся в стандартный поток ошибок (stderr). Если указан символ -,\n"
              "предупреждения выводятся в стандартный поток вывода (stdout). Если файл не\n"
              "может быть открыт, предупреждения по-прежнему выводятся в stderr."
          );
  doc->add(
              "INPUT",
              "Тег INPUT используется для указания файлов и/или каталогов, содержащих\n"
              "документированные исходные файлы. Вы можете вводить имена файлов, такие как\n"
              "myfile.cpp, или каталоги, такие как /usr/src/myproject. Разделяйте файлы или\n"
              "каталоги пробелами. См. также FILE_PATTERNS и EXTENSION_MAPPING\n"
              "Примечание: Если этот тег оставлен пустым, будет выполнен поиск в текущем\n"
              "каталоге."
          );
  doc->add(
              "INPUT_ENCODING",
              "Тег INPUT_ENCODING задаёт кодировку символов, используемую во входных файлах,\n"
              "которую Doxygen использует для внутреннего хранения. По умолчанию используется\n"
              "кодировка UTF-8. Для кодировок, несовместимых с ASCII (например, KOI8-R),\n"
              "необходимо убедиться, что утилита iconv присутствует в системе. Для задания\n"
              "кодировки отдельных файлов см. тег INPUT_FILE_ENCODING.\n"
              "Значение по умолчанию: UTF-8."
          );
  doc->add(
              "INPUT_FILE_ENCODING",
              "Этот тег можно использовать для указания кодировки символов исходных файлов,\n"
              "которые Doxygen обрабатывает. Тег INPUT_FILE_ENCODING позволяет задать\n"
              "кодировку символов для отдельных шаблонов файлов. Doxygen будет сравнивать имя\n"
              "файла с каждым шаблоном и применять кодировку вместо стандартной\n"
              "INPUT_ENCODING при совпадении. Кодировки символов — это список форматов,\n"
              "разделённых запятыми, вида filepattern=encoding. Шаблоны работают так же, как\n"
              "в теге FILE_PATTERNS. Если ни один шаблон не соответствует имени файла, будет\n"
              "использована кодировка по умолчанию."
          );
  doc->add(
              "FILE_PATTERNS",
              "Если значение тега INPUT содержит каталоги, можно использовать тег\n"
              "FILE_PATTERNS для указания одного или нескольких шаблонов (например, *.cpp и\n"
              "*.h) для фильтрации исходных файлов в каталогах.\n"
              "\n"
              "Обратите внимание: для пользовательских или не поддерживаемых напрямую\n"
              "расширений файлов также необходимо задать EXTENSION_MAPPING для этого\n"
              "расширения, иначе файлы не будут правильно обработаны Doxygen.*.c, *.cc,\n"
              "*.cxx, *.cxxm, *.cpp, *.cppm, *.ccm, *.c++, *.c++m, *.java, *.ii, *.ixx,\n"
              "*.ipp, *.i++, *.inl, *.idl, *.ddl, *.odl, *.h, *.hh, *.hxx, *.hpp, *.h++, *.l,\n"
              "*.cs, *.d, *.php, *.php4, *.php5, *.phtml, *.inc, *.m, *.markdown, *.md, *.mm,\n"
              "*.dox (to be provided as Doxygen C comment), *.py, *.pyw, *.f90, *.f95, *.f03,\n"
              "*.f08, *.f18, *.f, *.for, *.vhd, *.vhdl, *.ucf, *.qsfи*.ice."
          );
  doc->add(
              "RECURSIVE",
              "Если тег RECURSIVE установлен в YES, для поиска входных файлов будут также\n"
              "рекурсивно просматриваться подкаталоги.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXCLUDE",
              "Тег EXCLUDE можно использовать для указания файлов и/или каталогов, которые\n"
              "должны быть исключены из исходных файлов INPUT. Таким образом можно легко\n"
              "исключить подкаталог из дерева каталогов, корень которого указан тегом INPUT.\n"
              "\n"
              "Обратите внимание: относительные пути вычисляются относительно каталога, из\n"
              "которого запускается Doxygen."
          );
  doc->add(
              "EXCLUDE_SYMLINKS",
              "Если тег EXCLUDE_SYMLINKS установлен в YES, символические ссылки (на файлы или\n"
              "каталоги) будут исключены из входных данных.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXCLUDE_PATTERNS",
              "Если значение тега INPUT содержит каталоги, можно использовать тег\n"
              "EXCLUDE_PATTERNS для указания одного или нескольких шаблонов для исключения\n"
              "определённых файлов из этих каталогов.\n"
              "\n"
              "Обратите внимание: шаблоны сопоставляются с файлом с абсолютным путём, поэтому\n"
              "для исключения, например, всех тестовых каталогов используйте шаблон */test/*"
          );
  doc->add(
              "EXCLUDE_SYMBOLS",
              "Тег EXCLUDE_SYMBOLS можно использовать для указания одного или нескольких\n"
              "символьных имён (пространств имён, классов, функций и т.д.), которые должны\n"
              "быть исключены из документации. Символ может быть также частично\n"
              "квалифицированным именем, например: ANamespace, AClass, ANamespace::AClass,\n"
              "AClass::myFunction, AClass::* (для всех членов класса)."
          );
  doc->add(
              "EXAMPLE_PATH",
              "Тег EXAMPLE_PATH можно использовать для указания одного или нескольких файлов\n"
              "или каталогов, содержащих примеры исходного кода. Эти файлы используются\n"
              "командой \\include."
          );
  doc->add(
              "EXAMPLE_PATTERNS",
              "Если значение тега EXAMPLE_PATH содержит каталоги, вы можете использовать тег\n"
              "EXAMPLE_PATTERNS для указания одного или нескольких шаблонов для фильтрации\n"
              "файлов в этих каталогах."
          );
  doc->add(
              "EXAMPLE_RECURSIVE",
              "Если тег EXAMPLE_RECURSIVE установлен в YES, поиск примеров файлов будет\n"
              "выполняться рекурсивно в подкаталогах каталогов, указанных в теге\n"
              "EXAMPLE_PATH. Это полезно при использовании команд \\include и \\dontinclude.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "IMAGE_PATH",
              "Тег IMAGE_PATH можно использовать для указания одного или нескольких\n"
              "каталогов, содержащих файлы изображений, включаемых в документацию (см.\n"
              "команду \\image)."
          );
  doc->add(
              "INPUT_FILTER",
              "Тег INPUT_FILTER можно использовать для указания программы, которую Doxygen\n"
              "должен вызывать для фильтрации каждого входного файла. Doxygen вызовет\n"
              "программу-фильтр, исполняя (через popen()) команду:\n"
              "\n"
              "<filter> <input-file>\n"
              "\n"
              "где <filter> — значение тега INPUT_FILTER, а <input-file> — имя входного\n"
              "файла. Doxygen будет использовать вывод, который программа-фильтр записывает в\n"
              "стандартный вывод. Если задан тег FILTER_PATTERNS, данный тег будет\n"
              "проигнорирован.\n"
              "\n"
              "Обратите внимание: фильтр не должен добавлять или удалять строки; он\n"
              "применяется до сканирования кода, но не во время генерации выходного кода.\n"
              "Если строки добавляются или удаляются, якоря будут расставлены неверно.\n"
              "\n"
              "Обратите внимание: Doxygen будет использовать данные, обработанные и\n"
              "записанные в стандартный вывод, для дальнейшей обработки, поэтому ничего\n"
              "другого — например, отладочные операторы или использованные команды (в случае\n"
              "bat-файла Windows всегда используйте @echo OFF) — не должно записываться в\n"
              "стандартный вывод.\n"
              "\n"
              "Обратите внимание: для пользовательских или не поддерживаемых напрямую\n"
              "расширений файлов также необходимо задать EXTENSION_MAPPING для этого\n"
              "расширения, иначе файлы не будут правильно обработаны Doxygen.\n"
              ""
          );
  doc->add(
              "FILTER_PATTERNS",
              "Тег FILTER_PATTERNS можно использовать для указания фильтров для определённых\n"
              "шаблонов файлов. Формат:\n"
              "шаблон=программа\n"
              "Здесь шаблон сопоставляется с полным именем файла (включая путь). Для\n"
              "сопоставления можно использовать символы подстановки. Применяется первое\n"
              "совпадающее правило, и файл фильтруется программой. Если заданный шаблон не\n"
              "соответствует ни одному правилу, к файлу применяется фильтр из тега\n"
              "INPUT_FILTER. Также см. тег EXTENSION_MAPPING."
          );
  doc->add(
              "FILTER_SOURCE_FILES",
              "Если тег FILTER_SOURCE_FILES установлен в YES, фильтры, указанные в тегах\n"
              "INPUT_FILTER и FILTER_PATTERNS, также будут применяться к входным исходным\n"
              "файлам, отображаемым в браузере кода (см. SOURCE_BROWSER).\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "FILTER_SOURCE_PATTERNS",
              "Тег FILTER_SOURCE_PATTERNS можно использовать для указания фильтров исходного\n"
              "кода для отдельных шаблонов файлов. Шаблон перекрывает настройку\n"
              "FILTER_PATTERN (если задана), а также возможно отключить фильтрацию исходных\n"
              "файлов для конкретного шаблона, используя *.ext= (то есть без указания\n"
              "фильтра).\n"
              "Этот тег требует, чтобы тег FILTER_SOURCE_FILES был установлен в YES."
          );
  doc->add(
              "USE_MDFILE_AS_MAINPAGE",
              "Если тег USE_MDFILE_AS_MAINPAGE содержит имя файла Markdown, являющегося\n"
              "частью входных данных, этот файл станет главной страницей документации\n"
              "(index.html). Это может быть полезно, если один из входных файлов — файл\n"
              "README.md."
          );
  doc->add(
              "IMPLICIT_DIR_DOCS",
              "Если тег IMPLICIT_DIR_DOCS установлен в YES, Doxygen автоматически добавит\n"
              "документацию ко всем каталогам, для которых во входных данных не задана\n"
              "команда \\dir. Документация для каждого каталога будет включать краткое\n"
              "описание на основе имени каталога, подробное описание на основе необязательной\n"
              "документации внутри подкаталога, а также список файлов и подкаталогов,\n"
              "найденных в этом каталоге. Установите в NO, если необходимо документировать\n"
              "только явно задокументированные каталоги. По умолчанию — YES.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "FORTRAN_COMMENT_AFTER",
              "Тег FORTRAN_COMMENT_AFTER задаёт позицию в строке (в исходном коде в\n"
              "фиксированном формате Fortran), начиная с которой Doxygen распознаёт\n"
              "комментарии. По умолчанию это позиция 72, что соответствует стандарту Fortran\n"
              "77 для фиксированного формата. Уменьшение значения может пригодиться при\n"
              "работе с кодом, использующим более короткие строки.\n"
              "Минимальное значение: 7, максимальное значение: 10000, значение по умолчанию:\n"
              "72."
          );
  doc->add(
              "SOURCE_BROWSER",
              "Если тег SOURCE_BROWSER установлен в YES, в документации будет сгенерирован\n"
              "список исходных файлов, по которым можно перейти. Этот параметр полезен в\n"
              "сочетании с REFERENCED_BY_RELATION и REFERENCES_RELATION. Включение этого\n"
              "параметра также влияет на параметр VERBATIM_HEADERS.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "INLINE_SOURCES",
              "Если тег INLINE_SOURCES установлен в YES, тело функций, классов и\n"
              "перечислений, а также многострочные макросы и переменные с инициализатором-\n"
              "списком будут включены непосредственно в документацию.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "STRIP_CODE_COMMENTS",
              "Если тег STRIP_CODE_COMMENTS установлен в YES, специальные блоки\n"
              "документирующих комментариев будут скрыты в исходном коде в браузере, чтобы не\n"
              "захламлять код. Обычные комментарии на C, C++ и Fortran всегда остаются\n"
              "видимыми.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "REFERENCED_BY_RELATION",
              "Если тег REFERENCED_BY_RELATION установлен в YES, для каждой\n"
              "задокументированной функции будет показан список всех задокументированных\n"
              "функций, ссылающихся на неё.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "REFERENCES_RELATION",
              "Если тег REFERENCES_RELATION установлен в YES, для каждой документированной\n"
              "функции будет создан список всех документированных сущностей, которые\n"
              "вызываются/используются этой функцией.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "REFERENCES_LINK_SOURCE",
              "Если тег REFERENCES_LINK_SOURCE установлен в YES и тег SOURCE_BROWSER также\n"
              "установлен в YES, гиперссылки из функций в списках REFERENCES_RELATION и\n"
              "REFERENCED_BY_RELATION будут указывать на исходный код. В противном случае они\n"
              "будут указывать на документацию.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "SOURCE_TOOLTIPS",
              "Если тег SOURCE_TOOLTIPS установлен в YES и SOURCE_BROWSER также включён, при\n"
              "наведении мыши на ссылку в исходном коде будет отображаться всплывающая\n"
              "подсказка с прототипом и кратким описанием, а также ссылки для перехода к\n"
              "определению и документации символа.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег SOURCE_BROWSER был установлен в YES."
          );
  doc->add(
              "USE_HTAGS",
              "Если тег USE_HTAGS установлен в YES, ссылки на исходный код будут указывать на\n"
              "HTML, сгенерированный инструментом htags(1), вместо встроенного браузера\n"
              "исходного кода Doxygen. Инструмент htags входит в состав системы тегирования\n"
              "исходного кода GNU's global (см.\n"
              "https://www.gnu.org/software/global/global.html). Вам потребуется версия 4.8.6\n"
              "или выше.\n"
              "\n"
              "Для использования выполните следующие шаги:\n"
              "- Установите последнюю версию global\n"
              "- Включите SOURCE_BROWSER и USE_HTAGS в файле конфигурации\n"
              "- Убедитесь, что INPUT указывает на корень дерева исходников\n"
              "- Запустите doxygen обычным образом\n"
              "\n"
              "Doxygen вызовет htags (который, в свою очередь, вызовет gtags), поэтому эти\n"
              "инструменты должны быть доступны из командной строки (то есть находиться в\n"
              "пути поиска).\n"
              "\n"
              "Результат: вместо браузера исходного кода, сгенерированного Doxygen, ссылки\n"
              "на исходный код теперь будут указывать на вывод htags.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег SOURCE_BROWSER был установлен в YES."
          );
  doc->add(
              "VERBATIM_HEADERS",
              "Если тег VERBATIM_HEADERS установлен в YES, Doxygen будет включать дословную\n"
              "копию заголовочного файла перед документацией каждого класса.\n"
              "См. также: SOURCE_BROWSER.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "CLANG_ASSISTED_PARSING",
              "Если тег CLANG_ASSISTED_PARSING установлен в YES, будет использован\n"
              "синтаксический анализатор Clang (llvm.org) для более точного синтаксического\n"
              "анализа. Это особенно полезно для кода C++ с обширным использованием шаблонов.\n"
              "Для включения этой функциональности Doxygen должен быть собран с поддержкой\n"
              "libclang (см. CMake-опцию use_libclang).\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "CLANG_ADD_INC_PATHS",
              "Если тег CLANG_ASSISTED_PARSING установлен в YES и тег CLANG_ADD_INC_PATHS\n"
              "установлен в YES, Doxygen будет добавлять каталог каждого входного файла в\n"
              "пути включения.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег CLANG_ASSISTED_PARSING был установлен в YES."
          );
  doc->add(
              "CLANG_OPTIONS",
              "Если включён анализ с помощью Clang, можно передать компилятору параметры\n"
              "командной строки, которые вы обычно используете при вызове компилятора.\n"
              "Обратите внимание, что пути включения уже будут установлены Doxygen для файлов\n"
              "и каталогов, указанных с помощью INPUT и INCLUDE_PATH.\n"
              "Этот тег требует, чтобы тег CLANG_ASSISTED_PARSING был установлен в YES."
          );
  doc->add(
              "CLANG_DATABASE_PATH",
              "Тег CLANG_DATABASE_PATH можно использовать для указания пути к каталогу,\n"
              "содержащему базу данных компиляции compile_commands.json, сгенерированную,\n"
              "например, утилитой CMake с опцией -DCMAKE_EXPORT_COMPILE_COMMANDS=ON. Наличие\n"
              "этой базы данных позволяет Doxygen точнее определять параметры компиляции для\n"
              "каждого входного файла. Если параметр не задан (по умолчанию), Clang будет\n"
              "использовать параметры из тегов INCLUDE_PATH и CLANG_OPTIONS."
          );
  doc->add(
              "ALPHABETICAL_INDEX",
              "Если тег ALPHABETICAL_INDEX установлен в YES, будет создан алфавитный\n"
              "указатель всех задокументированных элементов. Включение этого параметра\n"
              "рекомендуется для проектов, содержащих большое количество классов, структур,\n"
              "объединений или интерфейсов.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "IGNORE_PREFIX",
              "Тег IGNORE_PREFIX можно использовать для указания одного или нескольких\n"
              "префиксов, которые должны игнорироваться при определении места элемента в\n"
              "алфавитном указателе. Например, если задан префикс ABC_, то класс ABCFoo будет\n"
              "отображён в разделе F в алфавитном указателе вместо раздела A.\n"
              "Этот тег требует, чтобы тег ALPHABETICAL_INDEX был установлен в YES."
          );
  doc->add(
              "GENERATE_HTML",
              "Если тег GENERATE_HTML установлен в YES, будет сгенерирован вывод HTML.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "HTML_OUTPUT",
              "Тег HTML_OUTPUT используется для указания выходного каталога для HTML файлов.\n"
              "Если введен относительный путь, он будет добавлен к пути, указанному\n"
              "OUTPUT_DIRECTORY.\n"
              "Каталог по умолчанию: html.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_FILE_EXTENSION",
              "Тег HTML_FILE_EXTENSION можно использовать для указания расширения файла для\n"
              "каждой сгенерированной HTML страницы. По умолчанию установлено в .html.\n"
              "Значение по умолчанию: .html.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_HEADER",
              "Тег HTML_HEADER можно использовать для указания пользовательского файла HTML-\n"
              "заголовка для каждой сгенерированной HTML-страницы. Если тег оставить пустым,\n"
              "Doxygen сгенерирует стандартный заголовок. Для получения корректного HTML\n"
              "заголовочный файл должен включать все скрипты и таблицы стилей, которые нужны\n"
              "Doxygen и которые зависят от используемых параметров конфигурации (например,\n"
              "от значения параметра GENERATE_TREEVIEW). Настоятельно рекомендуется начать с\n"
              "заголовка по умолчанию, выполнив команду\n"
              "doxygen -w html new_header.html new_footer.html new_stylesheet.css\n"
              "YourConfigFile\n"
              "а затем отредактировать файл new_header.html. Дополнительные сведения о том,\n"
              "как сгенерировать заголовок по умолчанию, который обычно использует Doxygen,\n"
              "см. в разделе \"Doxygen usage\".\n"
              "Примечание: Заголовок может изменяться, поэтому как правило необходимо\n"
              "повторно генерировать заголовок по умолчанию при обновлении до более новой\n"
              "версии Doxygen.Описание возможных маркеров и названий блоков см. в\n"
              "документации.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_FOOTER",
              "Тег HTML_FOOTER можно использовать для указания пользовательского HTML-подвала\n"
              "для каждой сгенерированной HTML-страницы. Если тег оставить пустым, Doxygen\n"
              "сгенерирует стандартный подвал. Для получения дополнительной информации о том,\n"
              "как сгенерировать стандартный подвал и какие специальные команды можно\n"
              "использовать внутри него, см. HTML_HEADER. Также см. раздел \"Doxygen usage\"\n"
              "для получения информации о том, как сгенерировать стандартный подвал,\n"
              "используемый Doxygen по умолчанию.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_STYLESHEET",
              "Тег HTML_STYLESHEET можно использовать для указания пользовательской каскадной\n"
              "таблицы стилей, используемой для каждой HTML-страницы. Её можно использовать\n"
              "для тонкой настройки внешнего вида HTML-вывода. Если оставить пустым, Doxygen\n"
              "сгенерирует таблицу стилей по умолчанию. См. также раздел \"Doxygen usage\" для\n"
              "получения информации о том, как сгенерировать таблицу стилей, которую Doxygen\n"
              "обычно использует.\n"
              "Примечание: Рекомендуется использовать HTML_EXTRA_STYLESHEET вместо этого\n"
              "тега, так как он более надёжен, и этот тег (HTML_STYLESHEET) в будущем будет\n"
              "устаревшим.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_EXTRA_STYLESHEET",
              "Тег HTML_EXTRA_STYLESHEET можно использовать для указания дополнительных\n"
              "пользовательских каскадных таблиц стилей, которые будут включены после\n"
              "стандартной таблицы стилей, созданной Doxygen. Используйте эту опцию для\n"
              "переопределения некоторых аспектов стиля. Это предпочтительнее, чем\n"
              "использование HTML_STYLESHEET, так как это не заменяет стандартную таблицу\n"
              "стилей и поэтому более надёжно для будущих обновлений. Doxygen скопирует файл\n"
              "таблицы стилей в выходной каталог.\n"
              "Примечание: Порядок дополнительных файлов таблиц стилей важен (например,\n"
              "последняя таблица стилей в списке переопределяет настройки предыдущей таблицы\n"
              "стилей в списке).\n"
              "Примечание: Поскольку в настоящее время невозможно переопределить стиль полосы\n"
              "прокрутки в Webkit/Chromium, стиль полосы прокрутки будет опущен в стандартном\n"
              "doxygen.css, если указана одна или несколько дополнительных таблиц стилей.\n"
              "Поэтому, если требуется пользовательская полоса прокрутки, её необходимо\n"
              "добавить явно.Пример см. в документации.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_EXTRA_FILES",
              "Тег HTML_EXTRA_FILES можно использовать для указания одного или нескольких\n"
              "дополнительных изображений или других исходных файлов, которые должны быть\n"
              "скопированы в выходной каталог HTML. Обратите внимание, что эти файлы будут\n"
              "скопированы в базовый выходной каталог HTML. Используйте тег $relpath^ в\n"
              "файлах HTML_HEADER и/или HTML_FOOTER для загрузки этих файлов. В файле\n"
              "HTML_STYLESHEET используйте только имя файла. Также обратите внимание, что\n"
              "файлы будут скопированы как есть; команды или теги недоступны.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_COLORSTYLE",
              "Тег HTML_COLORSTYLE можно использовать для указания, должен ли сгенерированный\n"
              "HTML вывод быть представлен в темной или светлой теме.\n"
              "Возможные значения:LIGHT всегда генерирует вывод в светлом режиме, DARK всегда\n"
              "генерирует вывод в темном режиме, AUTO_LIGHT автоматически устанавливает режим\n"
              "в соответствии с предпочтениями пользователя, использует светлый режим, если\n"
              "предпочтение не установлено (по умолчанию), AUTO_DARK автоматически\n"
              "устанавливает режим в соответствии с предпочтениями пользователя, использует\n"
              "темный режим, если предпочтение не установленоиTOGGLE позволяет пользователю\n"
              "переключаться между светлым и темным режимом с помощью кнопки.\n"
              "Значение по умолчанию: AUTO_LIGHT.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_COLORSTYLE_HUE",
              "Тег HTML_COLORSTYLE_HUE управляет цветом вывода HTML. Doxygen настроит цвета в\n"
              "таблице стилей и фоновом изображении на основе этого цвета. Оттенок\n"
              "указывается как угол на цветовом круге, см. https://en.wikipedia.org/wiki/Hue\n"
              "для получения дополнительной информации. Например, значение 0 представляет\n"
              "красный, 60 — желтый, 120 — зеленый, 180 — голубой, 240 — синий, 300 —\n"
              "фиолетовый, а 360 снова красный.\n"
              "Минимальное значение: 0, максимальное значение: 359, значение по умолчанию:\n"
              "220.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_COLORSTYLE_SAT",
              "Тег HTML_COLORSTYLE_SAT управляет чистотой (или насыщенностью) цветов в выводе\n"
              "HTML. Значение 0 заставит вывод использовать только оттенки серого. Значение\n"
              "255 даст самые яркие цвета.\n"
              "Минимальное значение: 0, максимальное значение: 255, значение по умолчанию:\n"
              "100.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_COLORSTYLE_GAMMA",
              "Тег HTML_COLORSTYLE_GAMMA управляет гамма-коррекцией, применяемой к компоненте\n"
              "яркости цветов в выводе HTML. Значения ниже 100 постепенно делают вывод\n"
              "светлее, а значения выше 100 делают вывод темнее. Значение, деленное на 100,\n"
              "является фактическим применяемым гамма-значением, поэтому 80 означает гамму\n"
              "0.8, значение 220 означает гамму 2.2, а 100 не изменяет гамму.\n"
              "Минимальное значение: 40, максимальное значение: 240, значение по умолчанию:\n"
              "80.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_DYNAMIC_MENUS",
              "Если тег HTML_DYNAMIC_MENUS установлен в YES, сгенерированная HTML\n"
              "документация будет содержать главный индекс с вертикальным навигационным меню,\n"
              "создаваемым динамически с помощью JavaScript. Если отключено, навигационный\n"
              "индекс будет состоять из многоуровневых вкладок, статически встроенных в\n"
              "каждую HTML страницу. Отключите эту опцию для поддержки браузеров без\n"
              "JavaScript, таких как браузер справки Qt.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_DYNAMIC_SECTIONS",
              "Если тег HTML_DYNAMIC_SECTIONS установлен в YES, сгенерированная HTML\n"
              "документация будет содержать разделы, которые можно скрыть и показать после\n"
              "загрузки страницы.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_CODE_FOLDING",
              "Если тег HTML_CODE_FOLDING установлен в YES, классы и функции могут быть\n"
              "динамически свернуты и развернуты в сгенерированном HTML исходном коде.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_COPY_CLIPBOARD",
              "Если тег HTML_COPY_CLIPBOARD установлен в YES, Doxygen покажет значок в правом\n"
              "верхнем углу фрагментов кода и текста, позволяющий пользователю копировать их\n"
              "содержимое в буфер обмена. Обратите внимание, что это работает только тогда,\n"
              "когда браузер поддерживает это и веб-страница обслуживается через безопасный\n"
              "контекст (see:\n"
              "https://www.w3.org/TR/secure-contexts/), т.е. используя протокол https: или\n"
              "file:.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_PROJECT_COOKIE",
              "Doxygen сохраняет некоторые настройки в браузере постоянно (например, через\n"
              "cookies). По умолчанию эти настройки применяются ко всем HTML страницам,\n"
              "которые Doxygen генерирует во всех проектах. Тег HTML_PROJECT_COOKIE можно\n"
              "использовать для сохранения настроек под проектно-специфичным ключом, так что\n"
              "пользовательские предпочтения будут храниться отдельно для каждого проекта.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_INDEX_NUM_ENTRIES",
              "С помощью HTML_INDEX_NUM_ENTRIES вы можете управлять предпочтительным\n"
              "количеством записей, отображаемых изначально в различных древовидных индексах;\n"
              "пользователь может позже динамически сворачивать и разворачивать записи.\n"
              "Doxygen развернет дерево до уровня, где видимо указанное количество записей\n"
              "(если только полностью свернутое дерево уже не превышает это количество).\n"
              "Таким образом, установка количества записей в 1 приведет к генерации полностью\n"
              "свернутого дерева по умолчанию. 0 — это специальное значение, указывающее на\n"
              "неограниченное количество записей, что приведет к генерации полностью\n"
              "развернутого дерева по умолчанию.\n"
              "Минимальное значение: 0, максимальное значение: 9999, значение по умолчанию:\n"
              "100.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "GENERATE_DOCSET",
              "Если тег GENERATE_DOCSET установлен в YES, будут сгенерированы дополнительные\n"
              "индексные файлы, которые могут использоваться как входные данные для\n"
              "интегрированной среды разработки Apple Xcode 3 (see:\n"
              "https://developer.apple.com/xcode/), введенной в OSX 10.5 (Leopard). Для\n"
              "создания набора документации Doxygen сгенерирует Makefile в выходном каталоге\n"
              "HTML. Запуск make создаст набор документации в этом каталоге, а запуск make\n"
              "install установит набор документации в\n"
              "~/Library/Developer/Shared/Documentation/DocSets, чтобы Xcode мог найти его\n"
              "при запуске. См. https://developer.apple.com/library/archive/featuredarticles/\n"
              "DoxygenXcode/_index.html для получения дополнительной информации.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "DOCSET_FEEDNAME",
              "Этот тег определяет имя набора документации. Набор документации предоставляет\n"
              "зонтичный термин, под которым могут быть сгруппированы несколько наборов\n"
              "документации от одного поставщика (например, компании или набора продуктов).\n"
              "Значение по умолчанию: Doxygen generated docs.\n"
              "Этот тег требует, чтобы тег GENERATE_DOCSET был установлен в YES."
          );
  doc->add(
              "DOCSET_FEEDURL",
              "Этот тег определяет URL набора документации. Набор документации предоставляет\n"
              "зонтичный термин, под которым могут быть сгруппированы несколько наборов\n"
              "документации от одного поставщика (например, компании или набора продуктов).\n"
              "Этот тег требует, чтобы тег GENERATE_DOCSET был установлен в YES."
          );
  doc->add(
              "DOCSET_BUNDLE_ID",
              "Этот тег указывает строку, которая должна однозначно идентифицировать пакет\n"
              "набора документации. Это должна быть строка в обратном доменном стиле,\n"
              "например com.mycompany.MyDocSet. Doxygen добавит .docset к имени.\n"
              "Значение по умолчанию: org.doxygen.Project.\n"
              "Этот тег требует, чтобы тег GENERATE_DOCSET был установлен в YES."
          );
  doc->add(
              "DOCSET_PUBLISHER_ID",
              "Тег DOCSET_PUBLISHER_ID указывает строку, которая должна однозначно\n"
              "идентифицировать издателя документации. Это должна быть строка в обратном\n"
              "доменном стиле, например com.mycompany.MyDocSet.documentation.\n"
              "Значение по умолчанию: org.doxygen.Publisher.\n"
              "Этот тег требует, чтобы тег GENERATE_DOCSET был установлен в YES."
          );
  doc->add(
              "DOCSET_PUBLISHER_NAME",
              "Тег DOCSET_PUBLISHER_NAME идентифицирует издателя документации.\n"
              "Значение по умолчанию: Publisher.\n"
              "Этот тег требует, чтобы тег GENERATE_DOCSET был установлен в YES."
          );
  doc->add(
              "GENERATE_HTMLHELP",
              "Если тег GENERATE_HTMLHELP установлен в YES, Doxygen генерирует три\n"
              "дополнительных HTML индексных файла: index.hhp, index.hhc и index.hhk.\n"
              "index.hhp — это файл проекта, который может быть прочитан Microsoft HTML Help\n"
              "Workshop в Windows. В начале 2021 года Microsoft убрала исходную страницу,\n"
              "включая ссылку для скачивания (HTML Help Workshop уже много лет находится в\n"
              "режиме обслуживания). Вы можете скачать HTML Help Workshop из веб-архива по\n"
              "адресу исполняемый файл установки (see:\n"
              "http://web.archive.org/web/20160201063255/https://download.microsoft.com/downl\n"
              "oad/0/A/9/0A939EF6-E31C-430F-A3DF-DFAE7960D564/htmlhelp.exe).\n"
              "\n"
              "HTML Help Workshop содержит компилятор, который может преобразовать весь HTML\n"
              "вывод, сгенерированный Doxygen, в один скомпилированный HTML файл (.chm).\n"
              "Скомпилированные HTML файлы теперь используются в качестве формата справки\n"
              "Windows 98 и в будущем заменят старый формат справки Windows (.hlp) на всех\n"
              "платформах Windows. Сжатые HTML файлы также содержат индекс, оглавление, и вы\n"
              "можете искать слова в документации. HTML Workshop также содержит просмотрщик\n"
              "для сжатых HTML файлов.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "CHM_FILE",
              "Тег CHM_FILE можно использовать для указания имени файла сгенерированного .chm\n"
              "файла. К файлу можно добавить путь, если результат не должен быть записан в\n"
              "выходной каталог html.\n"
              "Этот тег требует, чтобы тег GENERATE_HTMLHELP был установлен в YES."
          );
  doc->add(
              "HHC_LOCATION",
              "Тег HHC_LOCATION можно использовать для указания местоположения (абсолютный\n"
              "путь, включая имя файла) компилятора HTML помощи (hhc.exe). Если не пусто,\n"
              "Doxygen попытается запустить компилятор HTML помощи на сгенерированном\n"
              "index.hhp.\n"
              "Файл должен быть указан с полным путём.\n"
              "Этот тег требует, чтобы тег GENERATE_HTMLHELP был установлен в YES."
          );
  doc->add(
              "GENERATE_CHI",
              "Флаг GENERATE_CHI управляет тем, будет ли сгенерирован отдельный .chi\n"
              "индексный файл (YES) или включен в основной .chm файл (NO).\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTMLHELP был установлен в YES."
          );
  doc->add(
              "CHM_INDEX_ENCODING",
              "CHM_INDEX_ENCODING используется для кодирования содержимого индексного файла\n"
              "HtmlHelp (hhk), файла содержимого (hhc) и файла проекта.\n"
              "Этот тег требует, чтобы тег GENERATE_HTMLHELP был установлен в YES."
          );
  doc->add(
              "BINARY_TOC",
              "Флаг BINARY_TOC управляет тем, будет ли сгенерировано двоичное оглавление в\n"
              "файле .chm (YES) или обычное оглавление (NO). Кроме того, это включает кнопки\n"
              "Previous и Next.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTMLHELP был установлен в YES."
          );
  doc->add(
              "TOC_EXPAND",
              "Флаг TOC_EXPAND можно установить в YES, чтобы добавить дополнительные элементы\n"
              "для членов групп в оглавление и древовидное представление документации HTML\n"
              "помощи.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTMLHELP был установлен в YES."
          );
  doc->add(
              "SITEMAP_URL",
              "Тег SITEMAP_URL используется для указания полного URL места, где пользователь\n"
              "разместит сгенерированную документацию на сервере во время развертывания.\n"
              "Сгенерированная карта сайта называется sitemap.xml и помещается в каталог,\n"
              "указанный HTML_OUTPUT. Если SITEMAP_URL не указан, карта сайта не будет\n"
              "сгенерирована. Информацию о протоколе карты сайта см. на\n"
              "https://www.sitemaps.org\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "GENERATE_QHP",
              "Если тег GENERATE_QHP установлен в YES и заданы оба тега QHP_NAMESPACE и\n"
              "QHP_VIRTUAL_FOLDER, будет сгенерирован дополнительный индексный файл, который\n"
              "можно использовать в качестве входных данных для утилиты Qt qhelpgenerator для\n"
              "создания сжатого файла справки Qt (.qch) из сгенерированной HTML-документации.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "QCH_FILE",
              "Если указан тег QHG_LOCATION, тег QCH_FILE можно использовать для указания\n"
              "имени результирующего файла .qch. Указанный путь задаётся относительно папки\n"
              "вывода HTML.\n"
              "Этот тег требует, чтобы тег GENERATE_QHP был установлен в YES."
          );
  doc->add(
              "QHP_NAMESPACE",
              "Тег QHP_NAMESPACE задаёт пространство имён, используемое при генерации вывода\n"
              "Qt Help Project. Подробнее см. на странице Qt Help Project / Namespace (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#namespace).\n"
              "Значение по умолчанию: org.doxygen.Project.\n"
              "Этот тег требует, чтобы тег GENERATE_QHP был установлен в YES."
          );
  doc->add(
              "QHP_VIRTUAL_FOLDER",
              "Если тег GENERATE_QHP установлен в YES, тег QHP_VIRTUAL_FOLDER задаёт\n"
              "пространство имён, используемое при генерации вывода Qt Help Project.\n"
              "Подробнее см. на странице Qt Help Project / Virtual Folders (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#virtual-folders).\n"
              "Значение по умолчанию: doc.\n"
              "Этот тег требует, чтобы тег GENERATE_QHP был установлен в YES."
          );
  doc->add(
              "QHP_CUST_FILTER_NAME",
              "Тег QHP_CUST_FILTER_NAME задаёт имя добавляемого пользовательского фильтра.\n"
              "Подробнее см. на странице Qt Help Project / Custom Filters (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Этот тег требует, чтобы тег GENERATE_QHP был установлен в YES."
          );
  doc->add(
              "QHP_CUST_FILTER_ATTRS",
              "Тег QHP_CUST_FILTER_ATTRS указывает список атрибутов добавляемого\n"
              "пользовательского фильтра. Дополнительные сведения см. на странице Qt Help\n"
              "Project / Custom Filters (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Этот тег требует, чтобы тег GENERATE_QHP был установлен в YES."
          );
  doc->add(
              "QHP_SECT_FILTER_ATTRS",
              "Тег QHP_SECT_FILTER_ATTRS задаёт список атрибутов, которым должна\n"
              "соответствовать секция фильтра данного проекта. Qt Help Project / Filter\n"
              "Attributes (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#filter-attributes).\n"
              "Этот тег требует, чтобы тег GENERATE_QHP был установлен в YES."
          );
  doc->add(
              "QHG_LOCATION",
              "Тег QHG_LOCATION можно использовать для указания местоположения (абсолютный\n"
              "путь, включая имя файла) утилиты Qt qhelpgenerator. Если указано непустое\n"
              "значение, Doxygen попытается запустить qhelpgenerator для сгенерированного\n"
              "файла .qhp.\n"
              "Этот тег требует, чтобы тег GENERATE_QHP был установлен в YES."
          );
  doc->add(
              "GENERATE_ECLIPSEHELP",
              "Если тег GENERATE_ECLIPSEHELP установлен в YES, будут сгенерированы\n"
              "дополнительные индексные файлы; вместе с HTML-файлами они образуют плагин\n"
              "справки для Eclipse. Чтобы установить этот плагин и сделать его доступным в\n"
              "меню содержимого справки в Eclipse, содержимое каталога с HTML- и XML-файлами\n"
              "необходимо скопировать в каталог plugins Eclipse. Имя каталога внутри plugins\n"
              "должно совпадать со значением ECLIPSE_DOC_ID. После копирования Eclipse\n"
              "необходимо перезапустить, чтобы справка стала доступна.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "ECLIPSE_DOC_ID",
              "Уникальный идентификатор для плагина справки Eclipse. При установке плагина\n"
              "каталог, содержащий HTML- и XML-файлы, должен иметь это же имя. Каждый набор\n"
              "документации должен иметь собственный идентификатор.\n"
              "Значение по умолчанию: org.doxygen.Project.\n"
              "Этот тег требует, чтобы тег GENERATE_ECLIPSEHELP был установлен в YES."
          );
  doc->add(
              "DISABLE_INDEX",
              "Тег DISABLE_INDEX можно использовать для включения/отключения сжатого индекса\n"
              "(вкладок) в верхней части каждой HTML-страницы. При значении NO индекс\n"
              "включён, при значении YES — отключён. Поскольку вкладки индекса содержат ту же\n"
              "информацию, что и дерево навигации, можно установить эту опцию в YES при\n"
              "включении GENERATE_TREEVIEW.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "GENERATE_TREEVIEW",
              "Тег GENERATE_TREEVIEW используется для указания, следует ли генерировать\n"
              "древовидную индексную структуру для отображения иерархической информации. Если\n"
              "значение тега установлено в YES, будет сгенерирована боковая панель,\n"
              "содержащая древовидную индексную структуру (аналогичную той, которая\n"
              "генерируется для HTML Help). Для этого требуется браузер с поддержкой\n"
              "JavaScript, DHTML, CSS и фреймов (то есть любой современный браузер).\n"
              "Пользователям Windows, вероятно, удобнее использовать функцию HTML help. С\n"
              "помощью пользовательских таблиц стилей (см. HTML_EXTRA_STYLESHEET) можно\n"
              "дополнительно настроить внешний вид индекса (см. \"Fine-tuning the output\").\n"
              "Например, таблица стилей по умолчанию, генерируемая Doxygen, содержит пример\n"
              "того, как разместить изображение в корне дерева вместо PROJECT_NAME. Поскольку\n"
              "дерево содержит более детальную информацию, чем вкладки индекса, можно\n"
              "рассмотреть установку DISABLE_INDEX в YES при включении этой опции.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "PAGE_OUTLINE_PANEL",
              "Если тег PAGE_OUTLINE_PANEL установлен в YES, Doxygen создаст панель структуры\n"
              "на правой стороне вывода, отображающую все заголовки страницы в виде дерева.\n"
              "Если страница не содержит заголовков, панель структуры не отображается. Панель\n"
              "структуры отображается только при включённом параметре GENERATE_TREEVIEW.\n"
              "Примечание: Эта опция поддерживается только для формата вывода HTML.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "FULL_SIDEBAR",
              "Если параметр FULL_SIDEBAR установлен в YES, дерево навигации будет\n"
              "отображаться на левой стороне вывода. В противном случае на левой стороне\n"
              "будет показан только выбранный элемент. Если параметр GENERATE_TREEVIEW\n"
              "отключён, этот параметр не имеет эффекта.\n"
              "Примечание: Эта опция поддерживается только для формата вывода HTML.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "ENUM_VALUES_PER_LINE",
              "Тег ENUM_VALUES_PER_LINE можно использовать для задания количества значений\n"
              "перечисления, которые Doxygen будет группировать на одной строке в\n"
              "сгенерированной HTML-документации. Обратите внимание: значение 0 полностью\n"
              "подавляет вывод значений перечисления в разделе обзора.\n"
              "Минимальное значение: 0, максимальное значение: 20, значение по умолчанию: 4.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "SHOW_ENUM_VALUES",
              "Тег SHOW_ENUM_VALUES управляет отображением значений перечислений в выводе\n"
              "HTML.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "TREEVIEW_WIDTH",
              "Если включён treeview (см. GENERATE_TREEVIEW), данный тег можно использовать\n"
              "для задания начальной ширины (в пикселях) фрейма, в котором отображается\n"
              "дерево.\n"
              "Минимальное значение: 0, максимальное значение: 1500, значение по умолчанию:\n"
              "250.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "EXT_LINKS_IN_WINDOW",
              "Если тег EXT_LINKS_IN_WINDOW установлен в YES, внешние ссылки будут\n"
              "открываться в новом окне.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "OBFUSCATE_EMAILS",
              "Если тег OBFUSCATE_EMAILS установлен в YES, адреса электронной почты будут\n"
              "запутаны в выводе HTML.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "HTML_FORMULA_FORMAT",
              "Если параметр HTML_FORMULA_FORMAT установлен в svg, Doxygen будет использовать\n"
              "инструмент pdf2svg (см. https://github.com/dawbarton/pdf2svg) или inkscape\n"
              "(см. https://inkscape.org) для генерации формул в виде SVG-изображений вместо\n"
              "PNG для HTML-вывода. Эти изображения, как правило, выглядят лучше при\n"
              "масштабировании.\n"
              "Возможные значения:png (по умолчанию)иsvg (выглядит лучше, но требует\n"
              "инструмент pdf2svg или inkscape).\n"
              "Значение по умолчанию: png.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "FORMULA_FONTSIZE",
              "Тег FORMULA_FONTSIZE позволяет изменить размер шрифта для изображений формул\n"
              "LaTeX, включаемых в HTML-документацию. При изменении размера шрифта после\n"
              "успешного запуска Doxygen необходимо вручную удалить все изображения\n"
              "form_*.png из выходного каталога HTML, чтобы принудить Doxygen пересоздать их.\n"
              "Минимальное значение: 8, максимальное значение: 50, значение по умолчанию: 10.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "FORMULA_MACROFILE",
              "Файл FORMULA_MACROFILE может содержать команды LaTeX \\newcommanad и\n"
              "\\renewcommand для создания новых команд LaTeX, используемых в формулах как\n"
              "строительные блоки. Подробнее см. в разделе \"Including formulas\"."
          );
  doc->add(
              "USE_MATHJAX",
              "Включите параметр USE_MATHJAX для отрисовки формул LaTeX с помощью MathJax\n"
              "(см. https://www.mathjax.org), который использует JavaScript на стороне\n"
              "клиента вместо предварительно отрисованных растровых изображений. Используйте\n"
              "этот параметр, если у вас не установлен LaTeX или если вы хотите, чтобы\n"
              "формулы выглядели красивее в HTML-выводе. При включении может потребоваться\n"
              "отдельная установка MathJax и настройка пути к нему с помощью параметра\n"
              "MATHJAX_RELPATH.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "MATHJAX_VERSION",
              "С помощью MATHJAX_VERSION можно указать используемую версию MathJax. Обратите\n"
              "внимание, что разные версии MathJax имеют разные требования к различным\n"
              "настройкам, поэтому при переключении между разными версиями MathJax может\n"
              "потребоваться изменение других настроек MathJax.\n"
              "Возможные значения:MathJax_2, MathJax_3иMathJax_4.\n"
              "Значение по умолчанию: MathJax_2.\n"
              "Этот тег требует, чтобы тег USE_MATHJAX был установлен в YES."
          );
  doc->add(
              "MATHJAX_FORMAT",
              "При включении MathJax можно установить выходной формат по умолчанию для вывода\n"
              "MathJax. Для получения дополнительной информации о выходном формате см.\n"
              "MathJax версии 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/output.html), MathJax версии 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/output/index.html) и MathJax версии 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/output/index.htm).\n"
              "Возможные значения:HTML-CSS (медленнее, но имеет лучшую совместимость. Это имя\n"
              "для MathJax версии 2, для MathJax версии 3 будет переведено в chtml),\n"
              "NativeMML (т.е. MathML. Поддерживается только для MathJax 2. Для MathJax\n"
              "версии 3 вместо этого будет использоваться chtml.), chtml (Это имя для MathJax\n"
              "версии 3, для MathJax версии 2 будет переведено в HTML-CSS)иSVG.\n"
              "Значение по умолчанию: HTML-CSS.\n"
              "Этот тег требует, чтобы тег USE_MATHJAX был установлен в YES."
          );
  doc->add(
              "MATHJAX_RELPATH",
              "Когда MathJax включен, вам нужно указать расположение относительно выходного\n"
              "каталога HTML с помощью параметра MATHJAX_RELPATH. Для MathJax версии 2\n"
              "целевой каталог должен содержать скрипт MathJax.js. Например, если каталог\n"
              "mathjax находится на том же уровне, что и выходной каталог HTML, то\n"
              "MATHJAX_RELPATH должен быть ../mathjax. Для MathJax версий 3 и 4 целевой\n"
              "каталог должен содержать скрипт tex-<format>.js (где <format>\n"
              "- это chtml или svg). Значение по умолчанию указывает на сеть доставки\n"
              "контента MathJax, чтобы вы могли быстро увидеть результат без установки\n"
              "MathJax. Однако настоятельно рекомендуется установить локальную копию MathJax\n"
              "с https://www.mathjax.org перед развертыванием. Значение по умолчанию:\n"
              "- в случае MathJax версии 2: https://cdn.jsdelivr.net/npm/mathjax@2\n"
              "- в случае MathJax версии 3: https://cdn.jsdelivr.net/npm/mathjax@3\n"
              "- в случае MathJax версии 4: https://cdn.jsdelivr.net/npm/mathjax@4\n"
              "Этот тег требует, чтобы тег USE_MATHJAX был установлен в YES."
          );
  doc->add(
              "MATHJAX_EXTENSIONS",
              "Тег MATHJAX_EXTENSIONS можно использовать для указания одного или нескольких\n"
              "имен расширений MathJax, которые должны быть включены во время рендеринга\n"
              "MathJax. Например, для MathJax версии 2 (см.\n"
              "https://docs.mathjax.org/en/v2.7/tex.html):\n"
              "MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols\n"
              "Например, для MathJax версии 3 (см.\n"
              "https://docs.mathjax.org/en/v3.2/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = ams\n"
              "Например, для MathJax версии 4 (см.\n"
              "https://docs.mathjax.org/en/v4.0/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = units\n"
              "Обратите внимание, что для MathJax версии 4 довольно много расширений уже\n"
              "загружаются автоматически. Чтобы отключить пакет в MathJax версии 4, можно\n"
              "использовать имя пакета с префиксом в виде знака минус (- например\n"
              "MATHJAX_EXTENSIONS += -textmacros)\n"
              "Этот тег требует, чтобы тег USE_MATHJAX был установлен в YES."
          );
  doc->add(
              "MATHJAX_CODEFILE",
              "Тег MATHJAX_CODEFILE можно использовать для указания файла с фрагментами кода\n"
              "JavaScript, которые будут использоваться при запуске кода MathJax. Для\n"
              "получения дополнительной информации см. сайт MathJax:\n"
              "- MathJax версии 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/)\n"
              "- MathJax версии 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/)\n"
              "- MathJax версии 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/)Пример см. в документации.\n"
              "Этот тег требует, чтобы тег USE_MATHJAX был установлен в YES."
          );
  doc->add(
              "SEARCHENGINE",
              "Когда тег SEARCHENGINE включен, Doxygen создаст поле поиска для вывода HTML.\n"
              "Базовая поисковая система использует JavaScript и DHTML и должна работать в\n"
              "любом современном браузере. Обратите внимание, что при использовании справки\n"
              "HTML (GENERATE_HTMLHELP), справки Qt (GENERATE_QHP) или наборов документов\n"
              "(GENERATE_DOCSET) функция поиска уже есть, поэтому эту функцию обычно следует\n"
              "отключить. Для больших проектов поисковая система на основе JavaScript может\n"
              "работать медленно, тогда включение SERVER_BASED_SEARCH может обеспечить лучшее\n"
              "решение. Можно выполнять поиск с помощью клавиатуры; для перехода к полю\n"
              "поиска используйте <access key> + S (что такое <access key> зависит от\n"
              "операционной системы и браузера, но обычно это <CTRL>, <ALT>/<option> или\n"
              "оба). Внутри поля поиска используйте <cursor down key> для перехода к окну\n"
              "результатов поиска, по результатам можно перемещаться с помощью <cursor keys>.\n"
              "Нажмите <Enter> для выбора элемента или <escape> для отмены поиска. Параметры\n"
              "фильтра можно выбрать, когда курсор находится внутри поля поиска, нажав\n"
              "<Shift>+<cursor down>. Здесь также используйте <cursor keys> для выбора\n"
              "фильтра и <Enter> или <escape> для активации или отмены параметра фильтра.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_HTML был установлен в YES."
          );
  doc->add(
              "SERVER_BASED_SEARCH",
              "Когда тег SERVER_BASED_SEARCH включен, поисковая система будет реализована с\n"
              "использованием веб-сервера вместо веб-клиента на JavaScript. Существует два\n"
              "варианта поиска на основе веб-сервера в зависимости от настройки\n"
              "EXTERNAL_SEARCH. Когда отключено, Doxygen создаст PHP-скрипт для поиска и\n"
              "индексный файл, используемый скриптом. Когда EXTERNAL_SEARCH включено,\n"
              "индексация и поиск должны обеспечиваться внешними инструментами. См. раздел\n"
              "\"External Indexing and Searching\" для подробностей.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег SEARCHENGINE был установлен в YES."
          );
  doc->add(
              "EXTERNAL_SEARCH",
              "Когда тег EXTERNAL_SEARCH включен, Doxygen больше не будет создавать PHP-\n"
              "скрипт для поиска. Вместо этого результаты поиска записываются в XML-файл,\n"
              "который должен быть обработан внешним индексатором. Doxygen вызовет внешнюю\n"
              "поисковую систему, указанную в параметре SEARCHENGINE_URL, для получения\n"
              "результатов поиска.\n"
              "\n"
              "Doxygen поставляется с примером индексатора (doxyindexer) и поисковой системы\n"
              "(doxysearch.cgi), которые основаны на библиотеке поисковой системы с открытым\n"
              "исходным кодом Xapian (see:\n"
              "https://xapian.org/).\n"
              "\n"
              "См. раздел \"External Indexing and Searching\" для подробностей.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег SEARCHENGINE был установлен в YES."
          );
  doc->add(
              "SEARCHENGINE_URL",
              "SEARCHENGINE_URL должен указывать на поисковую систему, размещенную на веб-\n"
              "сервере, которая будет возвращать результаты поиска при включенном\n"
              "EXTERNAL_SEARCH.\n"
              "\n"
              "Doxygen поставляется с примером индексатора (doxyindexer) и поисковой системы\n"
              "(doxysearch.cgi), которые основаны на библиотеке поисковой системы с открытым\n"
              "исходным кодом Xapian (see:\n"
              "https://xapian.org/). См. раздел \"External Indexing and Searching\" для\n"
              "подробностей.\n"
              "Этот тег требует, чтобы тег SEARCHENGINE был установлен в YES."
          );
  doc->add(
              "SEARCHDATA_FILE",
              "Когда SERVER_BASED_SEARCH и EXTERNAL_SEARCH оба включены, неиндексированные\n"
              "данные поиска записываются в файл для индексации внешним инструментом. С\n"
              "помощью тега SEARCHDATA_FILE можно указать имя этого файла.\n"
              "Файл по умолчанию: searchdata.xml.\n"
              "Этот тег требует, чтобы тег SEARCHENGINE был установлен в YES."
          );
  doc->add(
              "EXTERNAL_SEARCH_ID",
              "Когда SERVER_BASED_SEARCH и EXTERNAL_SEARCH оба включены, тег\n"
              "EXTERNAL_SEARCH_ID может использоваться как идентификатор проекта. Это полезно\n"
              "в сочетании с EXTRA_SEARCH_MAPPINGS для поиска по нескольким проектам и\n"
              "перенаправления результатов обратно в правильный проект.\n"
              "Этот тег требует, чтобы тег SEARCHENGINE был установлен в YES."
          );
  doc->add(
              "EXTRA_SEARCH_MAPPINGS",
              "Тег EXTRA_SEARCH_MAPPINGS можно использовать для включения поиска по проектам\n"
              "Doxygen, отличным от определенного этим файлом конфигурации, но все\n"
              "добавленные в один и тот же внешний поисковый индекс. Каждый проект должен\n"
              "иметь уникальный идентификатор, установленный через EXTERNAL_SEARCH_ID.\n"
              "Сопоставление поиска затем сопоставляет идентификатор с относительным\n"
              "расположением, где можно найти документацию. Формат:\n"
              "EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...\n"
              "Этот тег требует, чтобы тег SEARCHENGINE был установлен в YES."
          );
  doc->add(
              "GENERATE_LATEX",
              "Если тег GENERATE_LATEX установлен в YES, будет сгенерирован вывод LaTeX.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "LATEX_OUTPUT",
              "Тег LATEX_OUTPUT используется для указания каталога, в который будут помещены\n"
              "документы LaTeX. Если задан относительный путь, перед ним будет подставлено\n"
              "значение OUTPUT_DIRECTORY.\n"
              "Каталог по умолчанию: latex.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_CMD_NAME",
              "Тег LATEX_CMD_NAME можно использовать для указания имени вызываемой команды\n"
              "LaTeX.\n"
              "\n"
              "Обратите внимание: если USE_PDFLATEX не включён, по умолчанию используется\n"
              "latex; если USE_PDFLATEX включён, по умолчанию используется pdflatex, и в этом\n"
              "случае, если выбрано latex, оно будет заменено на pdflatex. Для отдельных\n"
              "языков вывода значение по умолчанию может быть установлено иначе — это зависит\n"
              "от реализации поддержки соответствующего языка.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "MAKEINDEX_CMD_NAME",
              "Тег MAKEINDEX_CMD_NAME можно использовать для указания имени команды,\n"
              "генерирующей индекс для LaTeX.\n"
              "Примечание: Этот тег используется в Makefile / make.bat.\n"
              "См. также: LATEX_MAKEINDEX_CMD для части в генерируемом выходном файле (.tex).\n"
              "Файл по умолчанию: makeindex.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_MAKEINDEX_CMD",
              "Тег LATEX_MAKEINDEX_CMD можно использовать для указания имени команды,\n"
              "генерирующей индекс для LaTeX. Если первый символ не является обратной косой\n"
              "чертой (\\), она будет автоматически добавлена в код LaTeX.\n"
              "Примечание: Этот тег используется в генерируемом выходном файле (.tex).\n"
              "См. также: MAKEINDEX_CMD_NAME для части в Makefile / make.bat.\n"
              "Значение по умолчанию: makeindex.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "COMPACT_LATEX",
              "Если тег COMPACT_LATEX установлен в YES, Doxygen генерирует более компактную\n"
              "документацию LaTeX. Это может быть полезно для небольших проектов и помогает в\n"
              "целом сэкономить бумагу.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "PAPER_TYPE",
              "Тег PAPER_TYPE определяет размер бумаги для вывода LaTeX.\n"
              "Возможные значения:a4 (210 x 297 мм), letter (8.5 x 11 дюймов), legal (8.5 x\n"
              "14 дюймов)иexecutive (7.25 x 10.5 дюймов).\n"
              "Значение по умолчанию: a4.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "EXTRA_PACKAGES",
              "Тег EXTRA_PACKAGES можно использовать для указания одного или нескольких имён\n"
              "пакетов LaTeX, которые должны быть включены в вывод LaTeX. Пакет можно указать\n"
              "только по его имени или с необязательными аргументами для этого пакета. Если\n"
              "требуются пакеты с параметрами, необходимо указать список options=value в\n"
              "качестве первого аргумента:\n"
              "EXTRA_PACKAGES={options=list}packagename\n"
              "или\n"
              "EXTRA_PACKAGES=packagename\n"
              "Пример:\n"
              "EXTRA_PACKAGES={options=with-obsolete}acronym\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_HEADER",
              "Тег LATEX_HEADER можно использовать для указания пользовательского LaTeX\n"
              "заголовка для генерируемого документа LaTeX. Заголовок должен содержать всё\n"
              "вплоть до первой главы. Если оставить пустым, Doxygen сгенерирует стандартный\n"
              "заголовок. Настоятельно рекомендуется начать с заголовка по умолчанию,\n"
              "выполнив команду\n"
              "doxygen -w latex new_header.tex new_footer.tex new_stylesheet.sty\n"
              "а затем отредактировать файл new_header.tex. Дополнительные сведения о том,\n"
              "как сгенерировать заголовок по умолчанию, который обычно использует Doxygen,\n"
              "см. в разделе \"Doxygen usage\".\n"
              "\n"
              "Примечание: используйте пользовательский заголовок только если вы знаете, что\n"
              "делаете!\n"
              "Примечание: Заголовок может изменяться, поэтому как правило необходимо\n"
              "повторно генерировать заголовок по умолчанию при обновлении до более новой\n"
              "версии Doxygen.Описание возможных маркеров и названий блоков см. в\n"
              "документации.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_FOOTER",
              "Тег LATEX_FOOTER можно использовать для указания пользовательского нижнего\n"
              "колонтитула LaTeX для генерируемого документа LaTeX. Нижний колонтитул должен\n"
              "содержать всё после последней главы. Если оставить пустым, Doxygen сгенерирует\n"
              "стандартный нижний колонтитул. Для получения дополнительной информации о том,\n"
              "как сгенерировать стандартный нижний колонтитул и какие специальные команды\n"
              "можно использовать внутри него, см. LATEX_HEADER. Также см. раздел \"Doxygen\n"
              "usage\" для получения информации о том, как сгенерировать стандартный нижний\n"
              "колонтитул, используемый Doxygen по умолчанию. Примечание: используйте\n"
              "пользовательский нижний колонтитул только если знаете, что делаете!\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_EXTRA_STYLESHEET",
              "Тег LATEX_EXTRA_STYLESHEET можно использовать для указания дополнительных\n"
              "пользовательских таблиц стилей LaTeX, которые включаются после стандартных\n"
              "таблиц стилей, создаваемых Doxygen. С помощью этой опции можно переопределить\n"
              "некоторые аспекты стиля. Doxygen скопирует файлы таблиц стилей в выходной\n"
              "каталог.\n"
              "Примечание: Порядок дополнительных файлов таблиц стилей имеет значение\n"
              "(например, последняя таблица стилей в списке переопределяет настройки\n"
              "предыдущих таблиц в списке).\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_EXTRA_FILES",
              "Тег LATEX_EXTRA_FILES можно использовать для указания одного или нескольких\n"
              "дополнительных изображений или других исходных файлов, которые должны быть\n"
              "скопированы в выходной каталог LATEX_OUTPUT. Обратите внимание, что файлы\n"
              "копируются как есть; никакие команды или маркеры не доступны.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "PDF_HYPERLINKS",
              "Если тег PDF_HYPERLINKS установлен в YES, генерируемый LaTeX подготавливается\n"
              "для конвертации в PDF (с помощью ps2pdf или pdflatex). PDF-файл будет\n"
              "содержать гиперссылки (как в HTML-выводе) вместо номеров страниц. Это делает\n"
              "вывод удобным для просмотра в браузере PDF.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "USE_PDFLATEX",
              "Если тег USE_PDFLATEX установлен в YES, Doxygen будет использовать механизм,\n"
              "указанный в теге LATEX_CMD_NAME, для непосредственной генерации PDF-файла из\n"
              "файлов LaTeX. Установите этот параметр в YES для получения PDF-документации\n"
              "более высокого качества.\n"
              "Примечание: Начиная с Doxygen 1.8.16 Doxygen использует не pdflatex, а\n"
              "lualatex при работе с формулами MathJax, если только USE_PDFLATEX не\n"
              "установлен в NO.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_BATCHMODE",
              "Если тег LATEX_BATCHMODE установлен в YES, LaTeX будет выполняться в пакетном\n"
              "режиме.\n"
              "Возможные значения:NO то же, что и ERROR_STOP, YES то же, что и BATCH, BATCH В\n"
              "пакетном режиме на терминал ничего не выводится, ошибки прокручиваются так,\n"
              "как если бы <return> нажимался при каждой ошибке; отсутствующие файлы, которые\n"
              "TeX пытается ввести или запросить с клавиатуры (\\read на неоткрытом входном\n"
              "потоке), приводят к прерыванию задания, NON_STOP В режиме без остановки\n"
              "диагностическое сообщение появится на терминале, но взаимодействие с\n"
              "пользователем невозможно, как и в пакетном режиме, SCROLL В режиме прокрутки\n"
              "TeX остановится только для отсутствующих файлов или если необходим ввод с\n"
              "клавиатурыиERROR_STOP В режиме остановки при ошибке TeX останавливается при\n"
              "каждой ошибке, запрашивая вмешательство пользователя.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_HIDE_INDICES",
              "Тег LATEX_HIDE_INDICES можно использовать для необязательного скрытия глав-\n"
              "указателей из оглавления, которые генерируются Doxygen. Это полезно, если\n"
              "необходимо отображать только алфавитный указатель, а не все остальные индексы.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_BIB_STYLE",
              "Тег LATEX_BIB_STYLE можно использовать для указания стиля библиографии,\n"
              "например plainnat или ieeetr. См. https://en.wikipedia.org/wiki/BibTeX и \\cite\n"
              "для получения дополнительной информации.\n"
              "Значение по умолчанию: plainnat.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "LATEX_EMOJI_DIRECTORY",
              "Тег LATEX_EMOJI_DIRECTORY используется для указания (относительного или\n"
              "абсолютного) пути, из которого будут читаться изображения эмодзи. Если указан\n"
              "относительный путь, он вычисляется относительно каталога LATEX_OUTPUT. Если\n"
              "оставить пустым, будет использоваться каталог LATEX_OUTPUT.\n"
              "Этот тег требует, чтобы тег GENERATE_LATEX был установлен в YES."
          );
  doc->add(
              "GENERATE_RTF",
              "Если тег GENERATE_RTF установлен в YES, Doxygen будет генерировать вывод в\n"
              "формате RTF. Вывод RTF оптимизирован для Word 97 и может выглядеть не идеально\n"
              "в других редакторах/просмотрщиках RTF.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "RTF_OUTPUT",
              "Тег RTF_OUTPUT используется для указания каталога, в который будут помещены\n"
              "документы RTF. Если задан относительный путь, перед ним будет подставлено\n"
              "значение OUTPUT_DIRECTORY.\n"
              "Каталог по умолчанию: rtf.\n"
              "Этот тег требует, чтобы тег GENERATE_RTF был установлен в YES."
          );
  doc->add(
              "COMPACT_RTF",
              "Если тег COMPACT_RTF установлен в YES, Doxygen будет генерировать более\n"
              "компактные RTF-документы. Это может быть полезно для небольших проектов и в\n"
              "целом способствует экономии ресурсов.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_RTF был установлен в YES."
          );
  doc->add(
              "RTF_HYPERLINKS",
              "Установите тег RTF_HYPERLINKS в YES, если необходимо, чтобы ссылки в RTF-\n"
              "документе, сгенерированном Doxygen, работали. Установите эту опцию в NO, если\n"
              "вы хотите использовать RTF-файлы вместе с Microsoft Word. Microsoft Word\n"
              "некорректно поддерживает ссылки на именованные якоря внутри одного документа,\n"
              "а также не поддерживает ссылки на якоря в других документах. Поэтому\n"
              "гиперссылки в таких случаях будут отключены.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_RTF был установлен в YES."
          );
  doc->add(
              "RTF_STYLESHEET_FILE",
              "Загружает определения таблицы стилей из файла. Синтаксис аналогичен файлу\n"
              "конфигурации Doxygen, то есть представляет собой набор присваиваний.\n"
              "Необходимо указывать только замены; отсутствующие определения устанавливаются\n"
              "в значения по умолчанию. Информацию о генерации таблицы стилей по умолчанию,\n"
              "которую Doxygen обычно использует, см. также в разделе \"Fine-tuning the\n"
              "output\".\n"
              "Этот тег требует, чтобы тег GENERATE_RTF был установлен в YES."
          );
  doc->add(
              "RTF_EXTENSIONS_FILE",
              "Загружает определения расширений из файла. Синтаксис аналогичен файлу\n"
              "конфигурации Doxygen, то есть представляет собой набор присваиваний.\n"
              "Необходимо указывать только замены; отсутствующие определения устанавливаются\n"
              "в значения по умолчанию. Информацию о генерации файла расширений по умолчанию,\n"
              "который Doxygen обычно использует, см. также в разделе \"Fine-tuning the\n"
              "output\".\n"
              "Этот тег требует, чтобы тег GENERATE_RTF был установлен в YES."
          );
  doc->add(
              "RTF_EXTRA_FILES",
              "Тег RTF_EXTRA_FILES можно использовать для указания одного или нескольких\n"
              "дополнительных изображений или других исходных файлов, которые должны быть\n"
              "скопированы в каталог RTF_OUTPUT. Обратите внимание, что файлы копируются как\n"
              "есть; никакие команды или маркеры не доступны.\n"
              "Этот тег требует, чтобы тег GENERATE_RTF был установлен в YES."
          );
  doc->add(
              "GENERATE_MAN",
              "Если тег GENERATE_MAN установлен в YES, будет сгенерирован вывод страниц Man.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "MAN_OUTPUT",
              "Тег MAN_OUTPUT используется для указания каталога, в который будут помещены\n"
              "man-страницы. Если задан относительный путь, перед ним будет подставлено\n"
              "значение OUTPUT_DIRECTORY. Внутри каталога, указанного в MAN_OUTPUT, будет\n"
              "создан каталог man3.\n"
              "Каталог по умолчанию: man.\n"
              "Этот тег требует, чтобы тег GENERATE_MAN был установлен в YES."
          );
  doc->add(
              "MAN_EXTENSION",
              "Тег MAN_EXTENSION определяет расширение, добавляемое к сгенерированным man-\n"
              "страницам. Если секция руководства не начинается с цифры, перед ней\n"
              "добавляется цифра 3. Значение по умолчанию: .3.\n"
              "Значение по умолчанию: .3.\n"
              "Этот тег требует, чтобы тег GENERATE_MAN был установлен в YES."
          );
  doc->add(
              "MAN_SUBDIR",
              "Тег MAN_SUBDIR определяет имя каталога, создаваемого внутри MAN_OUTPUT, в\n"
              "который помещаются man-страницы. По умолчанию используется man с последующим\n"
              "значением MAN_EXTENSION без начальной точки.\n"
              "Этот тег требует, чтобы тег GENERATE_MAN был установлен в YES."
          );
  doc->add(
              "MAN_LINKS",
              "Если тег MAN_LINKS установлен в YES и Doxygen генерирует вывод в формате man,\n"
              "для каждой задокументированной сущности в реальных man-страницах будет создан\n"
              "дополнительный man-файл. Эти дополнительные файлы лишь ссылаются на реальную\n"
              "man-страницу, однако без них команда man не сможет найти нужную страницу.\n"
              "Значение по умолчанию: NO.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_MAN был установлен в YES."
          );
  doc->add(
              "GENERATE_XML",
              "Если тег GENERATE_XML установлен в YES, Doxygen создаст XML-файл, содержащий\n"
              "структуру кода вместе со всей документацией.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "XML_OUTPUT",
              "Тег XML_OUTPUT используется для указания каталога, в который будут помещены\n"
              "XML-страницы. Если задан относительный путь, перед ним будет подставлено\n"
              "значение OUTPUT_DIRECTORY.\n"
              "Каталог по умолчанию: xml.\n"
              "Этот тег требует, чтобы тег GENERATE_XML был установлен в YES."
          );
  doc->add(
              "XML_PROGRAMLISTING",
              "Если тег XML_PROGRAMLISTING установлен в YES, Doxygen будет включать листинги\n"
              "программ (с подсветкой синтаксиса и информацией о перекрёстных ссылках) в XML-\n"
              "вывод. Обратите внимание: включение этого параметра значительно увеличит объём\n"
              "XML-вывода.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_XML был установлен в YES."
          );
  doc->add(
              "XML_NS_MEMB_FILE_SCOPE",
              "Если тег XML_NS_MEMB_FILE_SCOPE установлен в YES, члены пространства имен в\n"
              "области файла будут включены в вывод XML.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_XML был установлен в YES."
          );
  doc->add(
              "GENERATE_DOCBOOK",
              "Если тег GENERATE_DOCBOOK установлен в YES, будет сгенерирован вывод DocBook.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "DOCBOOK_OUTPUT",
              "Тег DOCBOOK_OUTPUT используется для указания каталога, в который будут\n"
              "помещены страницы DocBook. Если задан относительный путь, перед ним будет\n"
              "подставлено значение OUTPUT_DIRECTORY.\n"
              "Каталог по умолчанию: docbook.\n"
              "Этот тег требует, чтобы тег GENERATE_DOCBOOK был установлен в YES."
          );
  doc->add(
              "GENERATE_AUTOGEN_DEF",
              "Если тег GENERATE_AUTOGEN_DEF установлен в YES, Doxygen сгенерирует файл\n"
              "определений AutoGen (.def), отражающий структуру кода, включая всю\n"
              "документацию. Обратите внимание: данная функция всё ещё является\n"
              "экспериментальной и неполной.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "GENERATE_SQLITE3",
              "Если тег GENERATE_SQLITE3 установлен в YES, Doxygen сгенерирует базу данных\n"
              "Sqlite3 с символами, найденными Doxygen, сохраненными в таблицах.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "SQLITE3_OUTPUT",
              "Тег SQLITE3_OUTPUT используется для указания, где будет размещена база данных\n"
              "Sqlite3. Если введен относительный путь, значение OUTPUT_DIRECTORY будет\n"
              "добавлено в начало.\n"
              "Каталог по умолчанию: sqlite3.\n"
              "Этот тег требует, чтобы тег GENERATE_SQLITE3 был установлен в YES."
          );
  doc->add(
              "SQLITE3_RECREATE_DB",
              "Если тег SQLITE3_RECREATE_DB установлен в YES, существующий файл базы данных\n"
              "doxygen_sqlite3.db будет создаваться заново при каждом запуске Doxygen. Если\n"
              "установлено в NO, Doxygen предупредит, если файл базы данных уже найден, и не\n"
              "изменит его.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_SQLITE3 был установлен в YES."
          );
  doc->add(
              "GENERATE_PERLMOD",
              "Если тег GENERATE_PERLMOD установлен в YES, Doxygen сгенерирует файл модуля\n"
              "Perl, который захватывает структуру кода (включая всю документацию).\n"
              "\n"
              "Обратите внимание: на данный момент эта функция всё ещё экспериментальна и не\n"
              "завершена.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "PERLMOD_LATEX",
              "Если тег PERLMOD_LATEX установлен в YES, включается генерация файла LaTeX из\n"
              "вывода PerlMod с использованием файла Doxyrules.make, создаваемого вместе с\n"
              "Perl-модулем.\n"
              "Примечание: Для этой опции требуется рабочая установка LaTeX.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег GENERATE_PERLMOD был установлен в YES."
          );
  doc->add(
              "PERLMOD_PRETTY",
              "Установите тег PERLMOD_PRETTY в YES для форматированного вывода генерируемого\n"
              "Perl-модуля. Если установить тег в NO, будет сгенерирован более компактный\n"
              "Perl-модуль.\n"
              "Примечание: Рекомендуется запустить perltidy для полученного Perl-модуля,\n"
              "чтобы дополнительно проверить его корректность.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег GENERATE_PERLMOD был установлен в YES."
          );
  doc->add(
              "PERLMOD_MAKEVAR_PREFIX",
              "Имена переменных make в генерируемом файле doxyrules.make дополняются\n"
              "префиксом, заданным в PERLMOD_MAKEVAR_PREFIX. Это полезно, когда несколько\n"
              "файлов doxyrules.make, включаемых одним Makefile, не должны перезаписывать\n"
              "переменные друг друга.\n"
              "Этот тег требует, чтобы тег GENERATE_PERLMOD был установлен в YES."
          );
  doc->add(
              "ENABLE_PREPROCESSING",
              "Если тег ENABLE_PREPROCESSING установлен в YES, препроцессор C будет применен\n"
              "к исходному коду.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "MACRO_EXPANSION",
              "Если тег MACRO_EXPANSION установлен в YES, Doxygen будет раскрывать все имена\n"
              "макросов в исходном коде. Если установлен в NO, будет выполняться только\n"
              "условная компиляция. Раскрытие макросов можно ограничить, установив\n"
              "EXPAND_ONLY_PREDEF в YES.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег ENABLE_PREPROCESSING был установлен в YES."
          );
  doc->add(
              "EXPAND_ONLY_PREDEF",
              "Если теги EXPAND_ONLY_PREDEF и MACRO_EXPANSION оба установлены в YES,\n"
              "раскрытие макросов ограничивается макросами, указанными в тегах PREDEFINED и\n"
              "EXPAND_AS_DEFINED.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег ENABLE_PREPROCESSING был установлен в YES."
          );
  doc->add(
              "SEARCH_INCLUDES",
              "Если тег SEARCH_INCLUDES установлен в YES, при обнаружении директивы #include\n"
              "будет выполняться поиск включаемых файлов в каталогах, указанных в\n"
              "INCLUDE_PATH.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег ENABLE_PREPROCESSING был установлен в YES."
          );
  doc->add(
              "INCLUDE_PATH",
              "Тег INCLUDE_PATH можно использовать для указания одного или нескольких\n"
              "каталогов, содержащих включаемые файлы, которые не являются входными файлами,\n"
              "но должны обрабатываться препроцессором. Обратите внимание, что INCLUDE_PATH\n"
              "не является рекурсивным, поэтому настройка RECURSIVE не влияет на него.\n"
              "Этот тег требует, чтобы тег SEARCH_INCLUDES был установлен в YES."
          );
  doc->add(
              "INCLUDE_FILE_PATTERNS",
              "Тег INCLUDE_FILE_PATTERNS позволяет задать один или несколько шаблонов\n"
              "подстановки (например, *.h и *.hpp) для фильтрации заголовочных файлов в\n"
              "каталогах. Если оставить пустым, будут использованы шаблоны, указанные в\n"
              "FILE_PATTERNS.\n"
              "Этот тег требует, чтобы тег ENABLE_PREPROCESSING был установлен в YES."
          );
  doc->add(
              "PREDEFINED",
              "Тег PREDEFINED можно использовать для указания одного или нескольких имён\n"
              "макросов, которые определяются до запуска препроцессора (аналогично опции -D\n"
              "для gcc). Аргументом тега является список макросов вида: name или\n"
              "name=definition (без пробелов). Если определение и знак \"=\" опущены,\n"
              "предполагается \"=1\". Чтобы предотвратить отмену определения макроса через\n"
              "#undef или рекурсивное раскрытие, используйте оператор := вместо оператора =.\n"
              "Этот тег требует, чтобы тег ENABLE_PREPROCESSING был установлен в YES."
          );
  doc->add(
              "EXPAND_AS_DEFINED",
              "Если теги MACRO_EXPANSION и EXPAND_ONLY_PREDEF оба установлены в YES, данный\n"
              "тег можно использовать для указания списка имён макросов, которые должны быть\n"
              "раскрыты. Будет использоваться определение макроса, найденное в исходных\n"
              "кодах. Используйте тег PREDEFINED, если нужно задать другое определение\n"
              "макроса, которое должно переопределять найденное в исходном коде.\n"
              "Этот тег требует, чтобы тег ENABLE_PREPROCESSING был установлен в YES."
          );
  doc->add(
              "SKIP_FUNCTION_MACROS",
              "Если тег SKIP_FUNCTION_MACROS установлен в YES, препроцессор Doxygen будет\n"
              "удалять все ссылки на функционально-подобные макросы, которые стоят отдельной\n"
              "строкой, имеют имя полностью в верхнем регистре и не заканчиваются точкой с\n"
              "запятой. Такие функциональные макросы обычно используются для шаблонного кода\n"
              "и могут нарушить работу парсера, если их не удалить.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег ENABLE_PREPROCESSING был установлен в YES."
          );
  doc->add(
              "TAGFILES",
              "Тег TAGFILES можно использовать для указания одного или нескольких файлов\n"
              "тегов. Для каждого файла тегов необходимо указать расположение внешней\n"
              "документации. Формат файла тегов без расположения следующий:\n"
              "TAGFILES = file1 file2 ...\n"
              "Добавление расположения для файлов тегов выполняется следующим образом:\n"
              "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
              "где loc1 и loc2 могут быть относительными или абсолютными путями или URL-\n"
              "адресами. Дополнительные сведения об использовании файлов тегов см. в разделе\n"
              "\"Linking to external documentation\".\n"
              "Примечание: Каждый файл тегов должен иметь уникальное имя (при этом имя НЕ\n"
              "включает путь). Если файл тегов не находится в каталоге, из которого\n"
              "запускается Doxygen, необходимо также указать путь к файлу тегов здесь."
          );
  doc->add(
              "GENERATE_TAGFILE",
              "Если после тега GENERATE_TAGFILE указано имя файла, Doxygen создаст файл тегов\n"
              "на основе считанных входных файлов. Подробнее об использовании файлов тегов\n"
              "см. в разделе \"Linking to external documentation\"."
          );
  doc->add(
              "ALLEXTERNALS",
              "Если тег ALLEXTERNALS установлен в YES, все внешние классы и пространства имён\n"
              "будут перечислены в индексе классов и пространств имён. Если установлено в NO,\n"
              "в списке будут отображаться только унаследованные внешние классы.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "EXTERNAL_GROUPS",
              "Если тег EXTERNAL_GROUPS установлен в YES, все внешние группы будут\n"
              "перечислены в индексе модулей. Если установлено в NO, в индексе модулей будут\n"
              "отображены только группы текущего проекта.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "EXTERNAL_PAGES",
              "Если тег EXTERNAL_PAGES установлен в YES, все внешние страницы будут включены\n"
              "в оглавление. Если установлено в NO, в оглавление будут включены только\n"
              "страницы текущего проекта.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "HIDE_UNDOC_RELATIONS",
              "Если тег HIDE_UNDOC_RELATIONS установлен в YES, недокументированные отношения\n"
              "будут скрыты в диаграммах классов.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "HAVE_DOT",
              "Если тег HAVE_DOT установлен в YES, Doxygen считает, что инструмент dot\n"
              "доступен через системный путь. Этот инструмент является частью Graphviz (см.:\n"
              "https://www.graphviz.org/), набора инструментов для визуализации графов от\n"
              "AT&T и Lucent Bell Labs. Остальные параметры данного раздела не имеют эффекта,\n"
              "если этот параметр установлен в NO.\n"
              "Значение по умолчанию: NO."
          );
  doc->add(
              "DOT_NUM_THREADS",
              "Тег DOT_NUM_THREADS задаёт количество вызовов dot, которые Doxygen может\n"
              "выполнять параллельно. При значении 0 Doxygen автоматически определяет это\n"
              "число на основе количества доступных процессоров. Можно явно задать значение\n"
              "больше 0, чтобы контролировать баланс между нагрузкой на CPU и скоростью\n"
              "обработки. Обратите внимание, что при многопоточной сборке вывод вызовов dot\n"
              "не является детерминированным; см. DOT_CLEANUP.\n"
              "Минимальное значение: 0, максимальное значение: 512, значение по умолчанию: 0.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOT_BATCH_SIZE",
              "DOT_BATCH_SIZE указывает количество dot-графов, которые Doxygen может\n"
              "скомпилировать за один вызов dot. При установке значения 1 Doxygen будет\n"
              "вызывать dot для каждого графа отдельно, что может привести к значительным\n"
              "накладным расходам на создание процессов, особенно на системах с большим\n"
              "количеством ядер ЦП. Вместе с DOT_NUM_THREADS этот параметр можно использовать\n"
              "для оптимизации скорости обработки dot для конкретной системы. Doxygen будет\n"
              "пытаться распределить нагрузку между потоками равномерно. Если общее\n"
              "количество графов для обработки превышает DOT_NUM_THREADS * DOT_BATCH_SIZE,\n"
              "будут созданы дополнительные пакеты для обработки dot.\n"
              "Минимальное значение: 1, максимальное значение: 1000, значение по умолчанию:\n"
              "50.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOT_COMMON_ATTR",
              "DOT_COMMON_ATTR — общие атрибуты для узлов, рёбер и меток подграфов. Если вы\n"
              "хотите использовать другой шрифт в dot-файлах, генерируемых Doxygen, можно\n"
              "указать атрибуты fontname, fontcolor и fontsize. Подробности см. в <a\n"
              "href=https://graphviz.org/doc/info/attrs.html>спецификации атрибутов узлов,\n"
              "рёбер и графов</a>. Необходимо убедиться, что dot может найти шрифт — это\n"
              "можно сделать, поместив его в стандартное место, или задав переменную\n"
              "окружения DOTFONTPATH, или установив DOT_FONTPATH в каталог, содержащий шрифт.\n"
              "Размер шрифта Graphviz по умолчанию — 14.\n"
              "Значение по умолчанию: fontname=Helvetica,fontsize=10.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOT_EDGE_ATTR",
              "DOT_EDGE_ATTR объединяется с DOT_COMMON_ATTR. Для элегантного стиля можно\n"
              "добавить 'arrowhead=open, arrowtail=open, arrowsize=0.5'. <a\n"
              "href=https://graphviz.org/doc/info/arrows.html>Полная документация о формах\n"
              "стрелок.</a>\n"
              "Значение по умолчанию: labelfontname=Helvetica,labelfontsize=10.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOT_NODE_ATTR",
              "DOT_NODE_ATTR объединяется с DOT_COMMON_ATTR. Для отображения без рамок\n"
              "вокруг узлов установите 'shape=plain' или 'shape=plaintext'. <a\n"
              "href=https://www.graphviz.org/doc/info/shapes.html>Спецификация форм.</a>\n"
              "Значение по умолчанию: shape=box,height=0.2,width=0.4.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOT_FONTPATH",
              "Вы можете задать путь, по которому dot может найти шрифт, указанный в атрибуте\n"
              "fontname в DOT_COMMON_ATTR и других атрибутах dot.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "CLASS_GRAPH",
              "Если тег CLASS_GRAPH установлен в YES, GRAPH или BUILTIN, Doxygen сгенерирует\n"
              "граф для каждого документированного класса, показывающий прямые и косвенные\n"
              "отношения наследования. Если тег CLASS_GRAPH установлен в YES или GRAPH, а\n"
              "также включён тег HAVE_DOT, то для построения графа будет использован\n"
              "инструмент dot. Если тег CLASS_GRAPH установлен в YES, а тег HAVE_DOT\n"
              "отключён, или если тег CLASS_GRAPH установлен в BUILTIN, будет использован\n"
              "встроенный генератор. Если тег CLASS_GRAPH установлен в TEXT, прямые и\n"
              "косвенные отношения наследования будут показаны в виде текста/ссылок. Явное\n"
              "включение графа наследования или выбор другого представления для графа\n"
              "наследования конкретного класса можно выполнить с помощью команды\n"
              "\\inheritancegraph. Отключение графа наследования можно выполнить с помощью\n"
              "команды \\hideinheritancegraph.\n"
              "Возможные значения:NO, YES, TEXT, GRAPHиBUILTIN.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "COLLABORATION_GRAPH",
              "Если тег COLLABORATION_GRAPH установлен в YES, Doxygen сгенерирует граф для\n"
              "каждого документированного класса, показывающий прямые и косвенные зависимости\n"
              "реализации (наследование, включение и ссылки на классы через переменные) этого\n"
              "класса с другими документированными классами. Явное включение графа\n"
              "коллаборации можно выполнить с помощью команды \\collaborationgraph. Отключение\n"
              "графа коллаборации можно выполнить с помощью команды \\hidecollaborationgraph.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "GROUP_GRAPHS",
              "Если тег GROUP_GRAPHS установлен в YES, Doxygen будет генерировать граф для\n"
              "групп, показывающий прямые зависимости между группами. См. также GROUP_GRAPHS\n"
              "для получения дополнительных сведений. Явное включение графа зависимостей\n"
              "группы можно выполнить с помощью команды \\groupgraph. Отключение графа\n"
              "зависимостей группы можно выполнить с помощью команды \\hidegroupgraph.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "UML_LOOK",
              "Если тег UML_LOOK установлен в YES, диаграммы наследования и сотрудничества\n"
              "будут сгенерированы в стиле, похожем на OMG Unified Modeling Language.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "UML_LIMIT_NUM_FIELDS",
              "Если тег UML_LOOK включён, поля и методы отображаются внутри узла класса. Если\n"
              "полей или методов очень много, а также много узлов, граф может стать слишком\n"
              "большим для практического использования. Порог UML_LIMIT_NUM_FIELDS\n"
              "ограничивает количество элементов каждого типа, чтобы сделать размер более\n"
              "управляемым. Установите значение 0 для снятия ограничения. Обратите внимание,\n"
              "что порог может быть превышен на 50% до того, как ограничение вступит в силу.\n"
              "Так, при пороге 10 может появиться до 15 полей, но если их количество превысит\n"
              "15, общее количество отображаемых полей будет ограничено 10.\n"
              "Минимальное значение: 0, максимальное значение: 100, значение по умолчанию:\n"
              "10.\n"
              "Этот тег требует, чтобы тег UML_LOOK был установлен в YES."
          );
  doc->add(
              "UML_MAX_EDGE_LABELS",
              "Если тег UML_LOOK включён, метки полей отображаются вдоль ребра между двумя\n"
              "узлами класса. Если полей и узлов очень много, граф может стать слишком\n"
              "загроможденным. Порог UML_MAX_EDGE_LABELS ограничивает количество элементов,\n"
              "чтобы сделать размер более управляемым. Установите значение 0 для снятия\n"
              "ограничения.\n"
              "Минимальное значение: 0, максимальное значение: 100, значение по умолчанию:\n"
              "10.\n"
              "Этот тег требует, чтобы тег UML_LOOK был установлен в YES."
          );
  doc->add(
              "DOT_UML_DETAILS",
              "Если тег UML_LOOK включён, поля и методы отображаются внутри узлов класса и\n"
              "структуры. Если полей или методов очень много, а также много узлов, граф может\n"
              "стать слишком большим для практического использования. Тег DOT_UML_DETAILS\n"
              "позволяет задать уровень детализации, отображаемой на графе:\n"
              "- NO: Отображаются только имена классов (без атрибутов и операций).\n"
              "- YES: Отображаются атрибуты и операции.\n"
              "- NONE: Атрибуты и операции не отображаются, блоки компактны (это может\n"
              "ускорить процесс рендеринга).\n"
              "Возможные значения:NO, YESиNONE.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег UML_LOOK был установлен в YES."
          );
  doc->add(
              "DOT_WRAP_THRESHOLD",
              "Тег DOT_WRAP_THRESHOLD можно использовать для задания минимального числа\n"
              "символов, после которого выполняется перенос строки. Каждый символ строки,\n"
              "превышающий этот порог, будет перенесён на новую строку. Установите значение\n"
              "0, чтобы отключить перенос.\n"
              "Минимальное значение: 0, максимальное значение: 1000, значение по умолчанию:\n"
              "17.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "TEMPLATE_RELATIONS",
              "Если тег TEMPLATE_RELATIONS установлен в YES, на диаграммах наследования и\n"
              "сотрудничества будут отображаться отношения между шаблонами и их экземплярами.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "INCLUDE_GRAPH",
              "Если теги INCLUDE_GRAPH, ENABLE_PREPROCESSING и SEARCH_INCLUDES установлены в\n"
              "YES, Doxygen сгенерирует граф для каждого документированного файла,\n"
              "показывающий прямые и косвенные зависимости включения этого файла от других\n"
              "документированных файлов. Значение по умолчанию: YES. Этот тег требует, чтобы\n"
              "тег HAVE_DOT был установлен в YES. Явное включение графа зависимостей\n"
              "включения можно выполнить с помощью команды \\includegraph. Отключение графа\n"
              "зависимостей включения можно выполнить с помощью команды \\hideincludegraph.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "INCLUDED_BY_GRAPH",
              "Если теги INCLUDED_BY_GRAPH, ENABLE_PREPROCESSING и SEARCH_INCLUDES\n"
              "установлены в YES, Doxygen сгенерирует граф для каждого документированного\n"
              "файла, показывающий прямые и косвенные зависимости включения этого файла от\n"
              "других документированных файлов. Значение по умолчанию: YES. Этот тег требует,\n"
              "чтобы тег HAVE_DOT был установлен в YES. Явное включение графа «включён в»\n"
              "можно выполнить с помощью команды \\includedbygraph. Отключение графа «включён\n"
              "в» можно выполнить с помощью команды \\hideincludedbygraph.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "CALL_GRAPH",
              "Если тег CALL_GRAPH установлен в YES, Doxygen будет генерировать граф\n"
              "зависимостей вызовов для каждой глобальной функции или метода класса. Обратите\n"
              "внимание: включение этой опции значительно увеличит время выполнения. Поэтому\n"
              "в большинстве случаев лучше включать графы вызовов только для выбранных\n"
              "функций с помощью команды \\callgraph. Отключение графа вызовов можно выполнить\n"
              "с помощью команды \\hidecallgraph.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "CALLER_GRAPH",
              "Если тег CALLER_GRAPH установлен в YES, Doxygen будет генерировать граф\n"
              "зависимостей вызывающих для каждой глобальной функции или метода класса.\n"
              "Обратите внимание: включение этой опции значительно увеличит время выполнения.\n"
              "Поэтому в большинстве случаев лучше включать графы вызывающих только для\n"
              "выбранных функций с помощью команды \\callergraph. Отключение графа вызывающих\n"
              "можно выполнить с помощью команды \\hidecallergraph.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "GRAPHICAL_HIERARCHY",
              "Если тег GRAPHICAL_HIERARCHY установлен в YES, иерархия классов будет\n"
              "отображаться графически.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DIRECTORY_GRAPH",
              "Если тег DIRECTORY_GRAPH установлен в YES, Doxygen будет графически показывать\n"
              "зависимости каталога от других каталогов. Зависимости определяются по\n"
              "отношениям #include между файлами в каталогах. Явное включение графа каталогов\n"
              "можно выполнить с помощью команды \\directorygraph. Отключение графа каталогов\n"
              "можно выполнить с помощью команды \\hidedirectorygraph.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DIR_GRAPH_MAX_DEPTH",
              "Тег DIR_GRAPH_MAX_DEPTH можно использовать для ограничения максимального\n"
              "количества уровней подкаталогов, генерируемых в диаграмме зависимостей\n"
              "каталогов.\n"
              "Минимальное значение: 1, максимальное значение: 25, значение по умолчанию: 1.\n"
              "Этот тег требует, чтобы тег DIRECTORY_GRAPH был установлен в YES."
          );
  doc->add(
              "DOT_IMAGE_FORMAT",
              "Если тег DOT_IMAGE_FORMAT установлен в svg, Doxygen будет генерировать SVG-\n"
              "изображения с поддержкой SGML. Обратите внимание: при использовании формата\n"
              "svg совместно с тегом HTML_FILE_EXTENSION, установленным в xhtml, SVG-файлы не\n"
              "кодируются в base64 и поэтому не могут быть встроены в XHTML-вывод. Для SVG-\n"
              "изображений возможны интерактивные эффекты при наведении курсора — для этого\n"
              "установите параметр INTERACTIVE_SVG в YES.\n"
              "Возможные значения:png, jpg, gif, svg, png:gd, png:gd:gd, png:cairo,\n"
              "png:cairo:gd, png:cairo:cairo, png:cairo:gdiplus, png:gdiplus,\n"
              "png:gdiplus:gdiplus, svg:cairo, svg:cairo:cairo, svg:svg, svg:svg:core,\n"
              "gif:cairo, gif:cairo:gd, gif:cairo:gdiplus, gif:gdiplus, gif:gdiplus:gdiplus,\n"
              "gif:gd, gif:gd:gd, jpg:cairo, jpg:cairo:gd, jpg:cairo:gdiplus, jpg:gd,\n"
              "jpg:gd:gd, jpg:gdiplusиjpg:gdiplus:gdiplus.\n"
              "Значение по умолчанию: png.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "INTERACTIVE_SVG",
              "Если тег INTERACTIVE_SVG установлен в YES, а DOT_IMAGE_FORMAT — в svg, при\n"
              "наведении курсора на узлы графа будет отображаться всплывающая подсказка с\n"
              "информацией об этом узле. Это удобно, поскольку большие графы бывают весьма\n"
              "сложными, и навигация по графу с помощью подсказок помогает понять его\n"
              "содержимое. Также можно установить INTERACTIVE_SVG в NO и при этом сохранить\n"
              "возможность масштабирования и перемещения. Для этого установите\n"
              "DOT_IMAGE_FORMAT в svg, а HTML_FILE_EXTENSION — в xhtml. В этом случае SVG\n"
              "встраивается непосредственно в HTML-документ.\n"
              "Значение по умолчанию: NO.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOT_PATH",
              "Тег DOT_PATH можно использовать для указания пути, по которому можно найти\n"
              "инструмент dot. Если оставить пустым, предполагается, что инструмент dot\n"
              "находится в переменной path.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOTFILE_DIRS",
              "Тег DOTFILE_DIRS можно использовать для указания одного или нескольких\n"
              "каталогов, содержащих dot-файлы, которые включаются в документацию (см.\n"
              "команду \\dotfile).\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DIA_PATH",
              "Вы можете включить диаграммы, созданные с помощью dia, в документацию Doxygen.\n"
              "Doxygen запустит dia для генерации диаграммы и вставит ее в документацию. Тег\n"
              "DIA_PATH позволяет указать каталог, где находится бинарный файл dia."
          );
  doc->add(
              "DIAFILE_DIRS",
              "Тег DIAFILE_DIRS можно использовать для указания одного или нескольких\n"
              "каталогов, содержащих файлы диаграмм Dia, включаемые в документацию (см.\n"
              "команду \\diafile)."
          );
  doc->add(
              "PLANTUML_JAR_PATH",
              "При генерации вывода Doxygen может использовать инструмент PlantUML\n"
              "(http://plantuml.com) для генерации диаграмм и схем. Тег PLANTUML_JAR_PATH\n"
              "должен использоваться для указания пути, по которому java может найти файл\n"
              "plantuml.jar, или имени jar-файла для использования. Если оставить пустым,\n"
              "предполагается, что PlantUML не используется или вызывается на этапе\n"
              "предварительной обработки. В этом случае Doxygen выдаст предупреждение при\n"
              "обнаружении команды \\startuml и не выполнит рендеринг диаграммы."
          );
  doc->add(
              "PLANTUML_CFG_FILE",
              "Тег PLANTUML_CFG_FILE можно использовать для указания файла конфигурации для\n"
              "PlantUML."
          );
  doc->add(
              "PLANTUML_INCLUDE_PATH",
              "Тег PLANTUML_INCLUDE_PATH можно использовать для указания путей включения для\n"
              "PlantUML."
          );
  doc->add(
              "PLANTUMLFILE_DIRS",
              "Тег PLANTUMLFILE_DIRS можно использовать для указания одного или нескольких\n"
              "каталогов, содержащих файлы диаграмм PlantUML, включаемые в документацию (см.\n"
              "команду \\plantumlfile)."
          );
  doc->add(
              "MERMAID_PATH",
              "Когда задан параметр MERMAID_PATH, Doxygen будет использовать локальную копию\n"
              "библиотеки Mermaid JS. Дополнительные сведения см. на странице\n"
              "https://mermaid.js.org/intro/getting-started.html.\n"
              "Примечание: Doxygen тестировался с Mermaid JS версии 10.9.0. При использовании\n"
              "другой версии некоторые диаграммы могут отображаться некорректно.\n"
              "Примечание: Если задан параметр MERMAID_PATH, параметр MERMAID_JS_URL\n"
              "использоваться не будет. В каталоге, указанном параметром MERMAID_PATH, должен\n"
              "находиться файл mermaid.min.js. Обратите внимание, что следует указывать путь\n"
              "(а не имя файла)."
          );
  doc->add(
              "MERMAID_CONFIG_FILE",
              "При использовании диаграмм Mermaid тег MERMAID_CONFIG_FILE можно использовать\n"
              "для указания файла конфигурации JSON для инструмента CLI Mermaid (mmdc)."
          );
  doc->add(
              "MERMAID_RENDER_MODE",
              "Тег MERMAID_RENDER_MODE выбирает, как рендерить диаграммы Mermaid.\n"
              "Возможные значения:AUTO (использовать рендеринг на стороне клиента для HTML и\n"
              "mmdc для LaTeX/PDF и других форматов. Если MERMAID_PATH не установлен, не-HTML\n"
              "диаграммы выдадут предупреждение), CLI (использовать инструмент mmdc для\n"
              "предварительной генерации изображений (требуется Node.js и mermaid-js/mermaid-\n"
              "cli). Работает для всех форматов вывода)иCLIENT_SIDE (встроить mermaid.js в\n"
              "вывод HTML для рендеринга на стороне клиента. Не требует mmdc, но работает\n"
              "только для вывода HTML).\n"
              "Значение по умолчанию: AUTO."
          );
  doc->add(
              "MERMAID_JS_URL",
              "Тег MERMAID_JS_URL указывает URL для загрузки mermaid.js при использовании\n"
              "клиентской отрисовки (MERMAID_RENDER_MODE равен CLIENT_SIDE или AUTO). По\n"
              "умолчанию указывается последний выпуск Mermaid v11 на CDN jsDelivr.\n"
              "\n"
              "CDN по умолчанию требует доступа в интернет при просмотре сгенерированной\n"
              "документации. Для использования без подключения к интернету скачайте\n"
              "mermaid.esm.min.mjs и укажите относительный путь, либо используйте\n"
              "MERMAID_RENDER_MODE=CLI для предварительной генерации изображений.\n"
              "Примеры:\n"
              "- Последняя v11 (по умолчанию):\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs\n"
              "- Фиксированная версия:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11.3.0/dist/mermaid.esm.min.mjs\n"
              "- Локальная копия: ./mermaid.esm.min.mjs (пользователь должен поместить файл\n"
              "в каталог HTML-вывода)\n"
              "Значение по умолчанию:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs."
          );
  doc->add(
              "MERMAIDFILE_DIRS",
              "Тег MERMAIDFILE_DIRS можно использовать для указания одного или нескольких\n"
              "каталогов, содержащих файлы диаграмм Mermaid, включаемые в документацию (см.\n"
              "команду \\mermaidfile)."
          );
  doc->add(
              "DOT_GRAPH_MAX_NODES",
              "Тег DOT_GRAPH_MAX_NODES можно использовать для задания максимального\n"
              "количества узлов, которые будут отображаться на графе. Если количество узлов в\n"
              "графе становится больше этого значения, Doxygen усечёт граф, визуализируя узел\n"
              "в виде красного прямоугольника. Обратите внимание: если количество прямых\n"
              "дочерних узлов корневого узла в графе уже превышает DOT_GRAPH_MAX_NODES, граф\n"
              "вообще не будет показан. Также обратите внимание, что размер графа может быть\n"
              "дополнительно ограничен с помощью MAX_DOT_GRAPH_DEPTH.\n"
              "Минимальное значение: 0, максимальное значение: 10000, значение по умолчанию:\n"
              "50.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "MAX_DOT_GRAPH_DEPTH",
              "Тег MAX_DOT_GRAPH_DEPTH можно использовать для задания максимальной глубины\n"
              "графов, генерируемых инструментом dot. Значение глубины 3 означает, что будут\n"
              "отображаться только узлы, достижимые из корневого узла по пути не более чем из\n"
              "3 рёбер. Узлы, расположенные дальше от корневого узла, будут опущены. Обратите\n"
              "внимание, что установка этой опции в 1 или 2 может значительно сократить время\n"
              "вычислений для больших кодовых баз. Также обратите внимание, что размер графа\n"
              "может быть дополнительно ограничен с помощью DOT_GRAPH_MAX_NODES.\n"
              "Использование глубины 0 означает отсутствие ограничения глубины.\n"
              "Минимальное значение: 0, максимальное значение: 1000, значение по умолчанию:\n"
              "0.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "GENERATE_LEGEND",
              "Если тег GENERATE_LEGEND установлен в YES, Doxygen сгенерирует страницу\n"
              "легенды, объясняющую значение различных блоков и стрелок в диаграммах,\n"
              "сгенерированных dot.\n"
              "Примечание: Этот тег требует, чтобы тег UML_LOOK не был установлен, то есть\n"
              "используется внутреннее графическое представление Doxygen для диаграмм\n"
              "наследования и сотрудничества.\n"
              "Значение по умолчанию: YES.\n"
              "Этот тег требует, чтобы тег HAVE_DOT был установлен в YES."
          );
  doc->add(
              "DOT_CLEANUP",
              "Если тег DOT_CLEANUP установлен в YES, Doxygen удалит промежуточные файлы,\n"
              "использованные для генерации различных графов.\n"
              "\n"
              "Примечание: Эта настройка используется не только для файлов dot, но и для\n"
              "временных файлов msc.\n"
              "Значение по умолчанию: YES."
          );
  doc->add(
              "MSCGEN_TOOL",
              "Вы можете определить диаграммы последовательности сообщений в комментариях\n"
              "Doxygen с помощью команды \\msc. Если тег MSCGEN_TOOL оставлен пустым (по\n"
              "умолчанию), Doxygen будет использовать встроенную версию инструмента mscgen\n"
              "для генерации диаграмм. Альтернативно, тег MSCGEN_TOOL также может указывать\n"
              "имя внешнего инструмента. Например, при указании значения prog, Doxygen будет\n"
              "вызывать инструмент как prog -T <outfile_format> -o <outputfile> <inputfile>.\n"
              "Внешний инструмент должен поддерживать форматы выходных файлов \"png\", \"eps\",\n"
              "\"svg\" и \"ismap\"."
          );
  doc->add(
              "MSCFILE_DIRS",
              "Тег MSCFILE_DIRS можно использовать для указания одного или нескольких\n"
              "каталогов, содержащих файлы диаграмм MSC, включаемые в документацию (см.\n"
              "команду \\mscfile)."
          );
}
